#!/bin/sh
#
# Define PATCHLEVEL to include the subversion id, if present.
#

MAJOR=1
MINOR=0
PATCH=4

PATCHLEVEL="${MAJOR}.${MINOR}.${PATCH}"

SVN=`which svn`

if [ -d .svn -a -x ${SVN} ]; then
  URL=$(${SVN} info | grep URL | awk '{print $2}')
  REV=$(${SVN} info ${URL} | grep Revision | awk '{print $2}')

  PATCHLEVEL="${PATCHLEVEL}.${REV}"
fi

TEMP="${1}.tmp"
DEST="${1}"

cat > $TEMP << EOF
/*
 *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
 *  patchlevel.h: A header defining the patchlevel.
 *
 *  Copyright (C) 2002 by the past and present ircd coders, and others.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  \$Id: patchlevel.h 260 2009-11-05 03:22:10Z srees $
 *  \$Hybrid: patchlevel.h 858 2007-02-28 04:15:47Z lusky $
 */

#ifndef PATCHLEVEL
#define PATCHLEVEL   "esphyb-${PATCHLEVEL}"
#endif
EOF

diff -q $TEMP $DEST 2>&1 >/dev/null

# difference
if [ ! $? -eq 0 ]; then
  mv -f $TEMP $DEST
else
  rm -f $TEMP
fi

echo "Patchlevel: ${PATCHLEVEL}"
