#include <stdlib.h>
#include <string.h>
#ifndef lint
#ifdef __unused
__unused
#endif
static char const 
yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.37.22.1 2008/07/21 01:13:33 kevlo Exp $";
#endif
#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYLEX yylex()
#define YYEMPTY -1
#define yyclearin (yychar=(YYEMPTY))
#define yyerrok (yyerrflag=0)
#define YYRECOVERING() (yyerrflag!=0)
#if defined(__cplusplus) || __STDC__
static int yygrowstack(void);
#else
static int yygrowstack();
#endif
#define YYPREFIX "yy"
#line 27 "ircd_parser.y"

#define YY_NO_UNPUT
#include <sys/types.h>

#include "stdinc.h"
#include "ircd.h"
#include "tools.h"
#include "list.h"
#include "s_conf.h"
#include "event.h"
#include "s_log.h"
#include "client.h"	/* for UMODE_ALL only */
#include "pcre.h"
#include "irc_string.h"
#include "irc_getaddrinfo.h"
#include "sprintf_irc.h"
#include "memory.h"
#include "modules.h"
#include "s_serv.h" /* for CAP_LL / IsCapable */
#include "hostmask.h"
#include "send.h"
#include "listener.h"
#include "resv.h"
#include "numeric.h"
#include "s_user.h"

#ifdef HAVE_LIBCRYPTO
#include <openssl/rsa.h>
#include <openssl/bio.h>
#include <openssl/pem.h>
#endif

static char *class_name = NULL;
static struct ConfItem *yy_conf = NULL;
static struct AccessItem *yy_aconf = NULL;
static struct MatchItem *yy_match_item = NULL;
static struct ClassItem *yy_class = NULL;
static char *yy_class_name = NULL;

static dlink_list col_conf_list  = { NULL, NULL, 0 };
static dlink_list hub_conf_list  = { NULL, NULL, 0 };
static dlink_list leaf_conf_list = { NULL, NULL, 0 };
static unsigned int listener_flags = 0;
static unsigned int regex_ban = 0;
static char userbuf[IRCD_BUFSIZE];
static char hostbuf[IRCD_BUFSIZE];
static char reasonbuf[REASONLEN + 1];
static char gecos_name[REALLEN * 4];

extern dlink_list gdeny_items; /* XXX */

static char *resv_reason = NULL;
static char *listener_address = NULL;
static int not_atom = 0;

struct CollectItem
{
  dlink_node node;
  char *name;
  char *user;
  char *host;
  char *passwd;
  int  port;
  int  flags;
#ifdef HAVE_LIBCRYPTO
  char *rsa_public_key_file;
  RSA *rsa_public_key;
#endif
};

static void
free_collect_item(struct CollectItem *item)
{
  MyFree(item->name);
  MyFree(item->user);
  MyFree(item->host);
  MyFree(item->passwd);
#ifdef HAVE_LIBCRYPTO
  MyFree(item->rsa_public_key_file);
#endif
  MyFree(item);
}

static void
unhook_hub_leaf_confs(void)
{
  dlink_node *ptr;
  dlink_node *next_ptr;
  struct CollectItem *yy_hconf;
  struct CollectItem *yy_lconf;

  DLINK_FOREACH_SAFE(ptr, next_ptr, hub_conf_list.head)
  {
    yy_hconf = ptr->data;
    dlinkDelete(&yy_hconf->node, &hub_conf_list);
    free_collect_item(yy_hconf);
  }

  DLINK_FOREACH_SAFE(ptr, next_ptr, leaf_conf_list.head)
  {
    yy_lconf = ptr->data;
    dlinkDelete(&yy_lconf->node, &leaf_conf_list);
    free_collect_item(yy_lconf);
  }
}

#line 135 "ircd_parser.y"
typedef union {
  int number;
  char *string;
} YYSTYPE;
#line 137 "y.tab.c"
#define YYERRCODE 256
#define ACCEPT_PASSWORD 257
#define ACTION 258
#define ADMIN 259
#define AFTYPE 260
#define T_ALLOW 261
#define ANTI_NICK_FLOOD 262
#define ANTI_SPAM_EXIT_MESSAGE_TIME 263
#define AUTOCONN 264
#define T_BLOCK 265
#define BURST_AWAY 266
#define BURST_TOPICWHO 267
#define BYTES 268
#define KBYTES 269
#define MBYTES 270
#define GBYTES 271
#define TBYTES 272
#define CALLER_ID_WAIT 273
#define CAN_FLOOD 274
#define CAN_IDLE 275
#define CHANNEL 276
#define CIDR_BITLEN_IPV4 277
#define CIDR_BITLEN_IPV6 278
#define CIPHER_PREFERENCE 279
#define CLASS 280
#define COMPRESSED 281
#define COMPRESSION_LEVEL 282
#define CONNECT 283
#define CONNECTFREQ 284
#define CRYPTLINK 285
#define DEFAULT_CIPHER_PREFERENCE 286
#define DEFAULT_FLOODCOUNT 287
#define DEFAULT_SPLIT_SERVER_COUNT 288
#define DEFAULT_SPLIT_USER_COUNT 289
#define DENY 290
#define DESCRIPTION 291
#define DIE 292
#define DISABLE_AUTH 293
#define DISABLE_FAKE_CHANNELS 294
#define DISABLE_HIDDEN 295
#define DISABLE_LOCAL_CHANNELS 296
#define DISABLE_REMOTE_COMMANDS 297
#define DOT_IN_IP6_ADDR 298
#define DOTS_IN_IDENT 299
#define DURATION 300
#define EGDPOOL_PATH 301
#define EMAIL 302
#define ENABLE 303
#define ENCRYPTED 304
#define EXCEED_LIMIT 305
#define EXEMPT 306
#define FAILED_OPER_NOTICE 307
#define FAKENAME 308
#define IRCD_FLAGS 309
#define FLATTEN_LINKS 310
#define FFAILED_OPERLOG 311
#define FKILLLOG 312
#define FKLINELOG 313
#define FGLINELOG 314
#define FIOERRLOG 315
#define FOPERLOG 316
#define FOPERSPYLOG 317
#define FUSERLOG 318
#define GECOS 319
#define GENERAL 320
#define GLINE 321
#define GLINES 322
#define GLINE_EXEMPT 323
#define GLINE_LOG 324
#define GLINE_TIME 325
#define GLINE_MIN_CIDR 326
#define GLINE_MIN_CIDR6 327
#define GLOBAL_KILL 328
#define IRCD_AUTH 329
#define NEED_IDENT 330
#define HAVENT_READ_CONF 331
#define HELP_CHANNEL 332
#define HIDDEN 333
#define HIDDEN_ADMIN 334
#define HIDDEN_NAME 335
#define HIDDEN_OPER 336
#define HIDE_SERVER_IPS 337
#define HIDE_SERVERS 338
#define HIDE_SPOOF_IPS 339
#define HOST 340
#define HUB 341
#define HUB_MASK 342
#define IDLETIME 343
#define IGNORE_BOGUS_TS 344
#define INVISIBLE_ON_CONNECT 345
#define IP 346
#define KILL 347
#define KILL_CHASE_TIME_LIMIT 348
#define KLINE 349
#define KLINE_EXEMPT 350
#define KLINE_REASON 351
#define KLINE_WITH_REASON 352
#define KNOCK_DELAY 353
#define KNOCK_DELAY_CHANNEL 354
#define LAZYLINK 355
#define LEAF_MASK 356
#define LINKS_DELAY 357
#define LISTEN 358
#define T_LOG 359
#define LOGGING 360
#define LOG_LEVEL 361
#define MAX_ACCEPT 362
#define MAX_BANS 363
#define MAX_CHANS_PER_USER 364
#define MAX_GLOBAL 365
#define MAX_IDENT 366
#define MAX_LOCAL 367
#define MAX_NICK_CHANGES 368
#define MAX_NICK_TIME 369
#define MAX_NUMBER 370
#define MAX_TARGETS 371
#define MESSAGE_LOCALE 372
#define MIN_NONWILDCARD 373
#define MIN_NONWILDCARD_SIMPLE 374
#define MODE_Z 375
#define MODULE 376
#define MODULES 377
#define NAME 378
#define NEED_PASSWORD 379
#define NETWORK_DESC 380
#define NETWORK_NAME 381
#define NICK 382
#define NICK_CHANGES 383
#define NO_CREATE_ON_SPLIT 384
#define NO_JOIN_ON_SPLIT 385
#define NO_OPER_FLOOD 386
#define NO_TILDE 387
#define NOT 388
#define NUMBER 389
#define NUMBER_PER_IDENT 390
#define NUMBER_PER_CIDR 391
#define NUMBER_PER_IP 392
#define NUMBER_PER_IP_GLOBAL 393
#define OPERATOR 394
#define OPERS_BYPASS_CALLERID 395
#define OPER_LOG 396
#define OPER_ONLY_UMODES 397
#define OPER_PASS_RESV 398
#define OPER_SPY_T 399
#define OPER_UMODES 400
#define JOIN_FLOOD_COUNT 401
#define JOIN_FLOOD_TIME 402
#define PACE_WAIT 403
#define PACE_WAIT_SIMPLE 404
#define PASSWORD 405
#define PATH 406
#define PING_COOKIE 407
#define PING_TIME 408
#define PING_WARNING 409
#define PORT 410
#define QSTRING 411
#define QUIET_ON_BAN 412
#define REASON 413
#define REDIRPORT 414
#define REDIRSERV 415
#define REGEX_T 416
#define REHASH 417
#define TREJECT_HOLD_TIME 418
#define REMOTE 419
#define REMOTEBAN 420
#define RESTRICT_CHANNELS 421
#define RESTRICTED 422
#define RSA_PRIVATE_KEY_FILE 423
#define RSA_PUBLIC_KEY_FILE 424
#define SSL_CERTIFICATE_FILE 425
#define RESV 426
#define RESV_EXEMPT 427
#define SECONDS 428
#define MINUTES 429
#define HOURS 430
#define DAYS 431
#define WEEKS 432
#define SENDQ 433
#define SEND_PASSWORD 434
#define SERVERHIDE 435
#define SERVERINFO 436
#define SERVLINK_PATH 437
#define SERVICES_NAME 438
#define IRCD_SID 439
#define TKLINE_EXPIRE_NOTICES 440
#define T_SHARED 441
#define T_CLUSTER 442
#define T_SNOOP 443
#define TYPE 444
#define SHORT_MOTD 445
#define SILENT 446
#define SPOOF 447
#define SPOOF_NOTICE 448
#define STATS_E_DISABLED 449
#define STATS_I_OPER_ONLY 450
#define STATS_K_OPER_ONLY 451
#define STATS_O_OPER_ONLY 452
#define STATS_P_OPER_ONLY 453
#define TBOOL 454
#define TMASKED 455
#define T_REJECT 456
#define TS_MAX_DELTA 457
#define TS_WARN_DELTA 458
#define TWODOTS 459
#define T_ALL 460
#define T_BOTS 461
#define T_SOFTCALLERID 462
#define T_CALLERID 463
#define T_CCONN 464
#define T_CCONN_FULL 465
#define T_CLIENT_FLOOD 466
#define T_DEAF 467
#define T_DEBUG 468
#define T_DRONE 469
#define T_EXTERNAL 470
#define T_FULL 471
#define T_INVISIBLE 472
#define T_IPV4 473
#define T_IPV6 474
#define T_LOCOPS 475
#define T_LOGPATH 476
#define T_L_CRIT 477
#define T_L_DEBUG 478
#define T_L_ERROR 479
#define T_L_INFO 480
#define T_L_NOTICE 481
#define T_L_TRACE 482
#define T_L_WARN 483
#define T_MAX_CLIENTS 484
#define T_NCHANGE 485
#define T_OPERWALL 486
#define T_REJ 487
#define T_SERVNOTICE 488
#define T_SKILL 489
#define T_SPY 490
#define T_SSL 491
#define T_UMODES 492
#define T_UNAUTH 493
#define T_UNRESV 494
#define T_UNXLINE 495
#define T_WALLOP 496
#define THROTTLE_TIME 497
#define TOPICBURST 498
#define TRUE_NO_OPER_FLOOD 499
#define TKLINE 500
#define TXLINE 501
#define TRESV 502
#define UNKLINE 503
#define USER 504
#define T_USERMODE 505
#define USE_EGD 506
#define USE_EXCEPT 507
#define USE_INVEX 508
#define USE_KNOCK 509
#define USE_LOGGING 510
#define USE_WHOIS_ACTUALLY 511
#define VHOST 512
#define VHOST6 513
#define XLINE 514
#define WARN 515
#define WARN_NO_NLINE 516
#define WEBIRC 517
const short yylhs[] = {                                        -1,
    0,    0,    5,    5,    5,    5,    5,    5,    5,    5,
    5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
    5,    5,    5,    5,    5,    2,    2,    1,    1,    1,
    1,    1,    1,    4,    4,    3,    3,    3,    3,   25,
   27,   27,   28,   28,   28,   29,   30,   13,   31,   31,
   32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
   32,   32,   32,   32,   45,   42,   33,   44,   36,   37,
   38,   39,   40,   34,   43,   41,   35,    6,   46,   46,
   47,   47,   47,   47,   48,   50,   49,    7,   51,   51,
   52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
   52,   52,   52,   53,   54,   57,   64,   58,   62,   59,
   60,   63,   61,   55,   55,   55,   55,   55,   55,   55,
   56,   66,    8,   65,   65,   67,   67,   69,   69,   69,
   69,   69,   69,   69,   69,   69,   69,   69,   69,   69,
   69,   69,   69,   69,   69,   69,   69,   69,   69,   69,
   69,   70,   68,   71,   72,   90,   91,   76,   93,   75,
   94,   94,   95,   95,   95,   95,   95,   95,   95,   95,
   95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
   95,   95,   77,   78,   84,   79,   80,   81,   82,   83,
   85,   86,   87,   73,   74,   88,   89,   96,   92,   97,
   97,  100,   98,  101,   98,   99,   99,   99,   99,   99,
   99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
   99,   99,  102,   26,  103,  103,  104,  104,  104,  105,
  106,  108,   10,  107,  107,  109,  109,  111,  111,  111,
  111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
  111,  112,  110,  115,  116,  118,  119,  120,  121,  122,
  123,  124,  113,  114,  117,  125,   11,  128,  127,  129,
  129,  130,  130,  126,  126,  131,  131,  131,  131,  131,
  136,  132,  135,  135,  137,  137,  133,  134,  138,   12,
  139,  139,  140,  140,  140,  140,  140,  140,  140,  140,
  140,  140,  140,  140,  140,  140,  140,  140,  140,  141,
  142,  151,  143,  156,  157,  144,  158,  158,  161,  159,
  162,  159,  160,  160,  160,  160,  160,  160,  160,  160,
  160,  160,  145,  146,  147,  154,  148,  149,  150,  152,
  153,  155,  163,   15,  164,  164,  165,  165,  165,  165,
  166,  167,  168,  169,   16,  170,  170,  171,  171,  171,
  171,  172,  173,  175,  174,  176,  176,  177,  177,  177,
  177,  177,  177,  177,  177,  177,  177,  177,  177,  178,
   17,  179,  179,  180,  180,  180,  181,  183,  182,  184,
  184,  185,  185,  185,  185,  185,  185,  185,  185,  185,
  185,  185,  187,   18,  186,  186,  188,  188,  190,  190,
  190,  190,  190,  190,  190,  190,  190,  190,  190,  190,
  190,  190,  190,  190,  190,  190,  190,  190,  191,  189,
  192,  193,  194,  195,  197,  196,  196,  198,  210,  199,
  211,  211,  214,  212,  215,  212,  213,  213,  213,  213,
  213,  213,  207,  204,  206,  205,  203,  209,  200,  201,
  202,  208,  216,   19,  219,  218,  220,  220,  221,  217,
  217,  222,  222,  222,  222,  223,  224,  225,   20,  226,
  226,  227,  227,  227,  228,  229,   21,  230,  230,  231,
  231,  232,  233,   24,  236,  235,  237,  237,  238,  234,
  234,  239,  239,  239,  239,  240,  241,   22,  242,  242,
  243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
  243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
  243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
  243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
  243,  243,  243,  243,  243,  243,  243,  243,  243,  243,
  243,  243,  243,  243,  243,  243,  243,  295,  296,  293,
  297,  298,  294,  254,  244,  245,  284,  246,  247,  248,
  249,  250,  251,  252,  253,  289,  255,  256,  257,  258,
  259,  299,  261,  266,  262,  262,  264,  264,  263,  278,
  279,  265,  267,  268,  269,  270,  272,  271,  260,  274,
  283,  285,  286,  275,  276,  291,  292,  288,  300,  277,
  301,  301,  302,  302,  302,  302,  302,  302,  302,  302,
  302,  302,  302,  302,  302,  302,  302,  302,  302,  302,
  302,  303,  273,  304,  304,  305,  305,  305,  305,  305,
  305,  305,  305,  305,  305,  305,  305,  305,  305,  305,
  305,  305,  305,  305,  305,  281,  282,  280,  287,  290,
  306,   23,  307,  307,  308,  308,  308,  308,  308,  308,
  308,  309,  310,  315,  311,  316,  316,  317,  317,  312,
  313,  318,  314,  319,  319,  320,  320,    9,  321,  321,
  322,  322,  322,  322,  322,  322,  322,  322,  322,  322,
  322,  322,  322,  322,  322,  322,  322,  322,  322,  340,
  335,  323,  324,  325,  326,  328,  329,  330,  331,  327,
  332,  333,  334,  336,  337,  338,  339,   14,  341,  341,
  342,  342,  342,  342,  342,  342,  342,  342,  343,  344,
  348,  345,  347,  346,  349,
};
const short yylen[] = {                                         2,
    0,    2,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    2,    2,    0,    1,    2,    3,    3,
    3,    3,    3,    0,    1,    2,    3,    3,    3,    5,
    2,    1,    1,    1,    2,    4,    4,    5,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    2,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    5,    2,    1,
    1,    1,    1,    2,    4,    4,    4,    5,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    2,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    0,    7,    0,    1,    2,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    2,    4,    1,    4,    4,    4,    4,    4,    0,    5,
    3,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    0,    5,    3,
    1,    0,    3,    0,    2,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    0,    6,    2,    1,    1,    1,    2,    4,
    4,    0,    7,    0,    1,    2,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    2,    4,    1,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    0,    6,    0,    5,    3,
    1,    1,    1,    2,    1,    1,    1,    1,    1,    2,
    0,    5,    3,    1,    1,    3,    4,    4,    0,    6,
    2,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    2,    4,
    4,    4,    4,    4,    0,    5,    3,    1,    0,    3,
    0,    2,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    0,    6,    2,    1,    1,    1,    1,    2,
    4,    4,    4,    0,    6,    2,    1,    1,    1,    1,
    2,    4,    4,    0,    5,    3,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    0,
    6,    2,    1,    1,    1,    2,    4,    0,    5,    3,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    0,    7,    0,    1,    2,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    2,    4,    1,
    4,    4,    4,    4,    4,    4,    4,    4,    0,    5,
    3,    1,    0,    3,    0,    2,    1,    1,    1,    1,
    1,    1,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    0,    6,    0,    5,    3,    1,    1,    2,
    1,    1,    1,    1,    1,    4,    4,    0,    6,    2,
    1,    1,    1,    1,    4,    4,    5,    2,    1,    1,
    1,    4,    0,    6,    0,    5,    3,    1,    1,    2,
    1,    1,    1,    1,    1,    4,    4,    5,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    0,    5,
    3,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    0,    5,    3,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    4,    4,    4,    4,    4,
    0,    6,    2,    1,    1,    1,    1,    1,    1,    1,
    1,    4,    4,    0,    5,    3,    1,    1,    1,    4,
    4,    0,    5,    3,    1,    1,    1,    5,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    5,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    4,    4,
    4,    4,    4,    4,    4,
};
const short yydefred[] = {                                      1,
    0,    0,    0,    0,  232,  403,  478,    0,  493,    0,
  671,  289,  463,  266,    0,    0,  122,  343,    0,    0,
  354,  380,  223,    2,    3,    4,    5,    6,    7,    8,
    9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
   19,   20,   21,   22,   23,   24,   25,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   80,   81,   82,   83,  719,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  700,  701,  702,
  703,  704,  705,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,  253,    0,  235,  430,
    0,  406,    0,  491,    0,    0,  489,  490,    0,  567,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  642,    0,  619,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  510,  511,  512,
  513,  514,  515,  516,  517,  518,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,  544,  545,  546,  547,  548,  549,  550,  551,  552,
  553,  554,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   90,   91,   92,   93,   94,   95,   96,   97,
   98,   99,  100,  101,  102,    0,    0,    0,    0,   42,
   43,   44,  153,    0,  125,    0,  748,    0,    0,    0,
    0,    0,    0,    0,    0,  740,  741,  742,  743,  744,
  745,  746,  747,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   50,   51,
   52,   53,   54,   55,   56,   57,   58,   59,   60,   61,
   62,   63,    0,    0,    0,   84,    0,    0,    0,    0,
   79,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  699,    0,    0,  484,    0,    0,    0,  481,  482,  483,
    0,    0,  488,  505,    0,    0,  495,    0,  504,  501,
  502,  503,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  509,
  681,  692,    0,    0,  684,    0,    0,    0,  674,  675,
  676,  677,  678,  679,  680,    0,    0,    0,    0,    0,
  315,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  292,  293,  294,  295,  296,  297,  298,
  299,  300,  301,  302,  303,  304,  305,  306,  307,  308,
  475,    0,  465,    0,    0,  474,  471,  472,  473,    0,
  268,    0,    0,    0,    0,  277,  275,  276,  278,  279,
  103,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   89,   45,    0,    0,    0,   41,
    0,    0,    0,    0,    0,    0,  346,  347,  348,  349,
    0,    0,    0,    0,    0,    0,    0,    0,  739,   64,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   49,    0,    0,  364,    0,    0,
  357,  358,  359,  360,    0,    0,  388,    0,  383,  384,
  385,    0,    0,    0,    0,  226,  227,  228,    0,    0,
    0,   78,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  698,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,  249,
  250,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  439,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  408,  409,  410,  411,  412,  413,  414,  415,
  416,  417,  418,  419,  420,  421,  422,  423,  424,  425,
  426,  427,    0,    0,    0,  480,    0,  487,    0,    0,
    0,    0,  500,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  508,    0,    0,    0,    0,    0,    0,    0,
  673,  309,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  291,
    0,    0,    0,    0,  470,  280,    0,    0,    0,    0,
    0,  274,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   88,    0,    0,   40,    0,    0,    0,    0,    0,  198,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  159,    0,    0,    0,    0,  127,
  128,  129,  130,  131,  132,  133,  134,  135,  136,  137,
  138,  139,  140,  141,  142,  143,  144,  145,  146,  147,
  148,  149,  150,  350,    0,    0,    0,    0,  345,    0,
    0,    0,    0,    0,    0,    0,  738,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   48,  361,    0,    0,    0,    0,  356,  386,    0,    0,
    0,  382,  229,    0,    0,    0,  225,   87,   86,   85,
  735,  732,  731,  720,  722,    0,    0,    0,    0,    0,
   27,   28,  726,  727,  730,  728,  733,  734,  736,  737,
  729,  721,  723,  724,  725,  251,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  236,  428,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  407,    0,    0,  479,  492,    0,    0,    0,
  494,  579,  583,  570,  600,  613,  612,  668,  617,  577,
  670,  609,  615,  578,  568,  569,  586,  575,  608,  576,
  589,  574,  588,  587,  582,  581,  580,  610,  607,  666,
  667,  590,  604,  601,  665,  646,  662,  663,  647,  648,
  649,  650,  657,  651,  660,  664,  653,  658,  654,  659,
  652,  656,  655,  661,    0,  645,  606,  623,  639,  640,
  624,  625,  626,  627,  634,  628,  637,  641,  630,  635,
  631,  636,  629,  633,  632,  638,    0,  622,  599,  602,
  616,  572,  611,  573,  603,  592,  597,  598,  595,  596,
  593,  594,  585,  584,    0,    0,    0,   35,   36,  669,
  618,  605,  614,  571,  591,    0,    0,    0,    0,    0,
    0,  672,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  290,    0,
    0,    0,  464,    0,    0,    0,    0,    0,  284,  267,
  107,  113,  111,  110,  112,  108,  109,  106,  114,  120,
  115,  119,  117,  118,  116,  105,  104,  121,   46,   47,
  151,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  126,    0,    0,    0,  344,
  754,  749,  753,  751,  755,  750,  752,   69,   73,   77,
   67,   71,   70,   66,   65,   72,   68,   76,   74,   75,
    0,    0,    0,  355,    0,    0,  381,    0,    0,  224,
   29,   30,   31,   32,   33,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  233,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  404,
  485,  486,  506,  507,  499,    0,  498,  643,    0,  620,
    0,   37,   38,   39,  697,  696,    0,  695,  683,  682,
  689,  688,    0,  687,  691,  690,  336,  313,  314,  335,
  319,    0,  318,    0,  338,  334,  333,  342,  337,  311,
  341,  340,  339,  312,  310,  477,  469,    0,  468,  476,
  273,  272,    0,  271,  288,  287,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  123,  352,  353,  351,  362,  368,  374,  379,
  377,  376,  373,  369,  372,  375,  370,  378,  371,    0,
  367,  363,  387,  392,  398,  402,  401,  400,  397,  393,
  396,  399,  394,  395,    0,  391,  230,  231,  263,  264,
  257,  259,  261,  260,  258,  252,  265,  256,  254,  255,
  262,  434,  436,  437,  457,  462,  461,  456,  455,  454,
  438,  443,    0,  442,    0,  431,  459,  460,  429,  435,
  453,  433,  458,  432,  496,    0,  644,  621,  693,    0,
  685,    0,    0,  316,    0,  327,  328,  324,  330,  326,
  325,  332,  329,  331,  323,  322,  466,    0,  269,    0,
  286,  283,  282,  193,  158,  191,  156,  202,    0,  201,
    0,  189,  183,  194,  195,  186,  152,  190,  155,  192,
  184,  185,  157,  197,  196,  182,  163,  179,  180,  164,
  165,  166,  167,  174,  168,  177,  181,  170,  175,  171,
  176,  169,  173,  172,  178,    0,  162,  188,  154,  187,
  365,    0,  389,    0,    0,  440,    0,  450,  451,  448,
  449,  447,  452,  446,  497,  694,  686,  320,  317,  467,
  270,    0,  199,    0,  214,  212,  221,  211,  206,  215,
  219,  208,  216,  218,  213,  207,  220,  222,  217,  209,
  210,  205,  160,    0,  366,  390,  444,  441,  203,  200,
  161,
};
const short yydgoto[] = {                                       1,
  921,  922, 1078, 1079,   24,   25,   26,   27,   28,   29,
   30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
   40,   41,   42,   43,   44,   45,  279,  280,  281,  282,
  318,  319,  320,  321,  322,  323,  324,  325,  326,  327,
  328,  329,  330,  331,  332,   73,   74,   75,   76,   77,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  284,   62,  839,  285,  840,  841,
  842,  843,  844,  845,  846,  847,  848,  849,  850,  851,
  852,  853,  854,  855,  856,  857,  858,  859,  860,  861,
  862,  863, 1161, 1466, 1467, 1146, 1429, 1430, 1512, 1492,
 1431,   68,  585,  586,  587,  588,  118,   50,  627,  119,
  628,  629,  630,  631,  632,  633,  634,  635,  636,  637,
  638,  639,  640,  641,   59,  505,  506,  787, 1293, 1294,
  507,  508,  509,  510, 1118, 1299, 1119,   57,  473,  474,
  475,  476,  477,  478,  479,  480,  481,  482,  483,  484,
  485,  486,  487,  488,  489,  490,  767, 1272, 1273, 1416,
 1403, 1274,   63,  536,  537,  538,  539,  540,   66,  570,
  571,  572,  573,  574,  894, 1340, 1341,   67,  578,  579,
  580,  581,  900, 1355, 1356,  121,   51,  662,  122,  663,
  664,  665,  666,  667,  668,  669,  670,  671,  672,  673,
  674,  675,  676,  677,  678,  679,  680,  681,  682,  962,
 1383, 1384, 1484, 1475, 1385,   58,  495,  496,  782, 1288,
 1289,  497,  498,  499,   52,  367,  368,  369,  370,  126,
  127,  128,   54,  378,  379,  691, 1246, 1247,  380,  381,
  382,  187,  188,  189,  190,  191,  192,  193,  194,  195,
  196,  197,  198,  199,  200,  201,  202,  203,  204,  205,
  206,  207,  208,  209,  210,  211,  212,  213,  214,  215,
  216,  217,  218,  219,  220,  221,  222,  223,  224,  225,
  226,  227,  228,  229,  230,  231,  232,  233,  234,  235,
  236,  237,  238,  239,  240,  241,  242,  243,  244,  418,
 1057, 1058,  416, 1035, 1036,   56,  448,  449,  450,  451,
  452,  453,  454,  455,  757, 1263, 1264,  754, 1257, 1258,
   97,   98,   99,  100,  101,  102,  103,  104,  105,  106,
  107,  108,  109,  110,  111,  112,  113,  114,  115,  116,
  295,  296,  297,  298,  299,  300,  301,  302,  303,
};
const short yysindex[] = {                                      0,
  298,  -24,  -87,  -85,    0,    0,    0,  -83,    0,  -65,
    0,    0,    0,    0,  -61,  -53,    0,    0,  -37,  -33,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -236,  749, -317,
 -314,    5, -234,    6,  416,    7,   27,   30,   34, -193,
 -237, -280,   36,  116,  199,   40,   47,   58,   74,  106,
  132,  133, -111,    0,    0,    0,    0,    0,  138,  141,
  150,  154,  159,  163,  170,  173,  177,  205,  210,  218,
  225,  226,  227,  229,  230,  234,  143,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   89,    0,    0,
  137,    0, -229,    0,  236, -113,    0,    0, -230,    0,
  237,  240,  244,  253,  255,  259,  261,  271,  272,  276,
  277,  278,  280,  281,  285,  295,  296,  303,  304,  305,
  306,  308,  309,  310,  312,  313,  315,  317,  320,  321,
  322,  326,  327,    0,  330,    0,  334,  340,  346,  351,
  352,  353,  357,  358,  359,  361,  362,  363,  364,  366,
  368,  369,  380,  381,  382,  385, -122,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, -142,  571, -247, -214,  213,  386,
  387,  389,  391,  396,  398,  399,  400,  402,  403,  404,
  405,   37,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  300,  409,  414, -107,    0,
    0,    0,    0,  356,    0, -226,    0,  434,  437,  439,
  440,  441,  442,  443,  333,    0,    0,    0,    0,    0,
    0,    0,    0,  450,  454,  455,  456,  458,  459,  460,
  461,  463,  464,  465,  468,  469,  472,  -78,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, -196, -205, -213,    0,  123,  125,  126,  479,
    0,   85,  152,  167,   98,  104,  174,  174,  176,  178,
  105,  112,  179,  174,  117,  118,  119,  121,  122,  523,
    0,  329,  631,    0,  522,  525, -109,    0,    0,    0,
  180,  531,    0,    0,  532,  533,    0, -104,    0,    0,
    0,    0,  130,  174,  144,  174,  206,  188,  214,  148,
  155,  156,  216,  197,  158,  222,  232,  242,  160,  174,
  161,  162,  243,  208,  169,  246,  247,  174,  250,  215,
  251,  252,  171,  190,  192,  572,  193,  581,  174,  174,
  195,  174,  249,  200,  201,  203, -406, -374,  207,  209,
  174,  174,  264,  174,  219,  220,  223,  231,  600,    0,
    0,    0,  601,  603,    0,  604,  606,  -68,    0,    0,
    0,    0,    0,    0,    0,  610,  615,  619,  620,  626,
    0,  627,  630,  632,  636,  639,  640,  643,  644,  645,
  647,  649,  182,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  655,    0,  657, -101,    0,    0,    0,    0,  625,
    0,  658,  671,  674,  -84,    0,    0,    0,    0,    0,
    0,  311,  325,  337,  338,  339,  341,  342,  343,  248,
  345,  347,  287,  685,    0,    0,  354,  355,  692,    0,
  550,  698,  702,  708,  709, -102,    0,    0,    0,    0,
  318,  319,  323,  360,  328,  332,  174,  716,    0,    0,
  370,  372,  344,  384,  388,  392,  393,  394,  397,  401,
  390,  406,  407,  721,    0,  733,  713,    0,  732, -119,
    0,    0,    0,    0,  737,  736,    0, -120,    0,    0,
    0,  741,  746,  761, -121,    0,    0,    0,  765,  766,
  767,    0,  769,  770,  772,  773,  774, -324,  776,  777,
  778,  779,  780,  781,  782,  784,  785,  787,  788,  789,
  790,    0,  793,  794,  796,  799,  801,  802,  803,  809,
  816,  818,  820,  822,  824,  828,  102,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  831,  832,  835,  836,  839,  841,  842,  843,  845,
  846,    0,  847,  848,  853,  857,  862,  863,  864,  865,
  868,  136,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  481,  519,  872,    0,  877,    0,  526,  527,
  881,  884,    0,  885,  886,  887,  889,  892,  893,  895,
  897,  898,  900,  901,  902,  904,  905,  907,  909,  916,
  918,  919,  920,  921,  922,  924,  925,  929,  931,  932,
  933,  935,  939,  940,  941,  942,  715,  943,  798,  944,
  945,  947,  948,  949,  952,  954,  955,  956,  958,  961,
  962,  963,  964,  965,  966, -191,  967,  968,  969,  970,
  972,  975,    0,  974,  174,  585,  979,  635,  637,  988,
    0,    0,  596,  641,  597,  605,  996,  607,  608,  609,
  612,  614,  656,  421,  659,  660,  618,  662,  999,    0,
  663, 1008,  665, 1018,    0,    0, 1021,  668,  673,  696,
 1027,    0, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035,
 1036, 1037, 1038, 1041, 1042, 1046, 1047, 1048, 1049, 1050,
    0, 1051, 1052,    0, 1055, 1054, 1058, 1059, 1060,    0,
 1061, 1067, 1069, 1070, 1071, 1074, 1075, 1077, 1078, 1079,
 1080, 1081, 1083, 1084,    0, 1085, 1087, 1088,  -15,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  742,  743,  744, 1093,    0, 1097,
 1098, 1100, 1101, 1103, 1104, 1106,    0, 1107, 1108, 1109,
 1110, 1112, 1113, 1114, 1115, 1122, 1125, 1129, 1130, 1132,
    0,    0,  786, 1131,  795, 1134,    0,    0,  806, 1135,
 1136,    0,    0,  813,  814, 1139,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  174,  174,  174,  174,  174,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  810,  821,  174,  838,
  840,  844,  854,  817,  856,  859,  174,  174,  264, 1148,
    0,    0,  819, -381,  755,  823,  860,  792,  797,  800,
  861, 1159,  866,  867,  869,  870,  875,  871,  878,  825,
  879, 1172,    0, 1173, 1176,    0,    0, 1183, 1190,  834,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    8,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   10,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  264,  264,  264,    0,    0,    0,
    0,    0,    0,    0,    0, -250, 1193, 1194, -248, 1196,
 1208,    0, 1215, 1216, 1217, 1233,  908, 1234, 1236, 1238,
 1239, 1240, 1241, 1242, 1243, 1244, 1245, 1246,    0, 1247,
  891, 1249,    0, -302, 1250, 1251,  852, 1268,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  873,  903,  874,  876, 1252,  880,  882,  883,  888,
  890,  906,  894,  910,  896,  899,  911,  912,  913,  914,
 1254,  915,  927,  917, 1257,    0, 1259, 1260, 1261,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1263,   48, 1265,    0, 1266,  623,    0, 1267, 1270,    0,
    0,    0,    0,    0,    0, 1272, 1273, 1274, 1276, 1280,
 1281, 1282, 1284, 1286, 1287, 1288, 1290, 1292,    0, 1293,
 1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302, 1303,  976,
 1304, 1307, 1311, 1313, 1314, 1315, 1316, 1317, 1318,    0,
    0,    0,    0,    0,    0,   12,    0,    0,  715,    0,
  798,    0,    0,    0,    0,    0,   15,    0,    0,    0,
    0,    0,   24,    0,    0,    0,    0,    0,    0,    0,
    0,   32,    0, -241,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   44,    0,    0,
    0,    0,   52,    0,    0,    0,  989,  696, 1320, 1321,
 1322, 1323, 1324,  997, 1325, 1327, 1328, 1329, 1330, 1331,
 1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339,  751, 1340,
 1341, 1342,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   54,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   56,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  151,    0, -256,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  834,    0,    0,    0, -250,
    0, -248, -241,    0,  908,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  891,    0, -302,
    0,    0,    0,    0,    0,    0,    0,    0,  157,    0,
  613,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  184,    0,    0,    0,    0,
    0,   48,    0,  623, -256,    0,  976,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  613,    0,  997,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  751,    0,    0,    0,    0,    0,    0,
    0,
};
const short yyrindex[] = {                                      0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1279,
 1283,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1285,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1344,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1345,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1344, 1344, 1344, 1344, 1344,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1345, 1345, 1345,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  471,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  211, 1346,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, -253,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  661,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  471,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, -253,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  661,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,
};
const short yygindex[] = {                                      0,
 -347, -435, -431,-1031,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1128,    0,    0,
    0, 1091,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1343,    0,    0,    0,
    0, 1149,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  573,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, -100,    0,    0,  -81,  -82,    0,
    0,    0,    0,  830,    0,    0,    0,    0,    0,    0,
  791,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   -3,
  923,    0,    0,    0,    0,    0,  124,    0,    0,  946,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   16,   17,
    0,    0,    0,    0,  926,    0,    0,    0,    0,    0,
  855,    0,    0,    0,    0,    0,  -49,    0,    0,  849,
    0,    0,    0,    0,  -50,    0,    0,    0,    0,  764,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  -48,  -45,    0,    0,    0,    0,    0,    0,    0,
   13,  937,    0,    0,    0,    0, 1066,    0,    0,    0,
 1308,    0,    0,    0,    0,    0,    0,   39, 1062,    0,
    0,    0, 1255,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  185,    0,    0,  189,    0,    0,  991,    0,    0,
    0,    0,    0,    0,    0,    0,   35,    0,    0,   41,
    0, 1347,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1150,    0,    0,    0,    0,    0,    0,    0,
};
#define YYTABLESIZE 1462
const short yytable[] = {                                     599,
  600,  747,  439,  906,  901,  896,  606, 1478,  491, 1479,
  445,  372,  445,  340, 1255,  685, 1261,  529,  276,   69,
  692,  124,  868,  784, 1480,  374,  364,  445, 1481,  532,
 1291,  445, 1406, 1407,   46,   48,  695,   49,  697,   53,
  791,  500,  582, 1252, 1253, 1254,  564,  738,  739,  533,
  575, 1249,  711, 1251,   70, 1396,  760,   55, 1400,  566,
  719,   60,  249, 1408,  598,   71, 1248, 1402, 1250,   61,
 1395,  730,  731, 1399,  733, 1405, 1075, 1076, 1077,  740,
  741, 1409, 1401,  744,  745,   64,  748, 1418, 1410,   65,
 1404, 1221, 1222,  117,  501, 1420,  120, 1472, 1482, 1474,
   47,  445, 1417,  916,  917,  918,  919,  920, 1411, 1165,
 1419,  125, 1471,  441, 1473,  442,  365,  250,  251,  252,
  253,  254,  255,  256,  257,  502,  583,  123,  129,  245,
  283,  503,  336,  130,  582,  575,  566, 1412,  277,  131,
  132,   72,  124,  133,   69, 1413,  364,  375,  276,  246,
  134,  374,  247,  532,  491,  534,  248,  443,  286,  135,
  444,  524,  333,  136,  137,  492,  337,  258,  278,  334,
  138,  500,  576,  533,  139,  140,  141,  304,  142,   70,
  335,  567,  376,  366,  143, 1414,  535,  441, 1292,  442,
   71,  584,  338,  339, 1477,  504,  493,  746,  342,  876,
 1494,  343,  259,  144,  145, 1256, 1415, 1262,  146, 1476,
  344,  362,  305,  377,  345, 1493,  147,  445,  583,  346,
  148,  149,  150,  347,  501,  151,  950, 1514,  152,  153,
  348,  443,  125,  349,  444,  446,  365,  350,  577,  154,
  815, 1483, 1513,  816,  445,  155,  156,  568,  157,  158,
  159,  160,  161,  306,  285,  502,  494,  576,  567,  363,
  972,  503,  307,  162,  817,  351,   72,  360,  277,  285,
  352,  511,  163,  375,  164,  165,  818,  166,  353,  534,
  167,  168,  260,  584,  169,  354,  355,  356,  819,  357,
  358,  445,  249,  820,  359,  170,  371,  383,  278,  308,
  384,  309,  310,  366,  385,  821,  779,  569,  376,  446,
  535,  492,  822,  386,  171,  387,  261,  172,  823,  388,
  824,  389,  173,  577,  568,  504,  174,  175,  176,  177,
  178,  390,  391,  825,  179,  180,  392,  393,  394,  377,
  395,  396,  493,  181,  311,  397,  312,  250,  251,  252,
  253,  254,  255,  256,  257,  398,  399,  613,  526,  313,
  314,  447,  826,  400,  401,  402,  403,  827,  404,  405,
  406,  287,  407,  408,  182,  409,  183,  410,  614,  615,
  411,  412,  413,  184,  569,  616,  414,  415,  185,  828,
  417,  642,  643,  186,  419,  644, 1328,  258,   78,  645,
  420,  829,  494,  830,  831,  315,  421, 1087,  832,   79,
  288,  422,  423,  424,  646,  647,  648,  425,  426,  427,
  649,  428,  429,  430,  431,  289,  432,  833,  433,  434,
   80,   81,  259,  316,  317,  447,   82,  456,   83,  650,
  435,  436,  437,  651,  652,  438,  512,  513,  290,  514,
  291,  515,  292,  293,  304,  457,  516,  548,  517,  518,
  519,  458,  520,  521,  522,  523,  617,  618,  619,  527,
  834,  620,  294, 1329,  528,  653,  835,  654,  531,  621,
 1201, 1202, 1203, 1204, 1205,  459,  460,  836,  837,  305,
  461,  655,  622,  623,  541,   84,   85,  542,  838,  543,
  544,  545,  546,  547,  462,   86,   87, 1330,  550,  624,
  625,  463,  260,  656,  551,  552,  553, 1218,  554,  555,
  556,  557, 1331,  558,  559,  560,   88,   89,  561,  562,
  306,  464,  563,  589,  626,  590,  591,  592,  593,  307,
  594, 1332, 1333,   90,   91,  657,  261, 1334, 1335, 1336,
 1337,  596, 1338,    2,   92,  595,    3,  597,  603,  658,
  465, 1339,  598,   93,  601,  604,  602,  605,  466,  659,
  607,  608,  609,    4,  610,  611,  308,    5,  309,  310,
    6,  612,  683,  694,  613,  684,  467,    7,  287,  688,
  687, 1208,  689,  690,  698,  468,  469,  696,  699, 1216,
 1217,  701,  700,    8,  704,  614,  615,  705,  702,  703,
  707,  706,  616,  710,  712,  713,    9,   10,  715,   11,
  708,  311,  716,  312,  724,  721,   12,  288,  470,  471,
  709,  714,  727,  660,  717,  718,  313,  314,  720,  722,
  723,  729,  289,  725,   13,  726,  728,  661,  732,   94,
   95,   96,  746,  735,  736,   14,  737,   15,  753,  734,
  742,  755,  743,  756,  758,  290,  759,  291,  762,  292,
  293,  130,  749,  750,   16,  763,  751,  131,  132,  764,
  765,  133,  315,  786,  752,  472,  766,  768,  134,  294,
  769,   17,  770,  617,  618,  619,  771,  135,  620,  772,
  773,  136,  137,  774,  775,  776,  621,  777,  138,  778,
  316,  317,  139,  140,  141,  781,  142,  783,  788,  622,
  623,  793,  143,   18,  801,  802,  803,  804,  805,  806,
  807,  789,   19,   20,  790,  794,  624,  625,   21,   22,
  810,  144,  145,  811,  321,  321,  146,  795,  796,  797,
  814,  798,  799,  800,  147,  808,  864,  809,  148,  149,
  150,  626,  865,  151,  812,  813,  152,  153,  866,  867,
  873,  870,  871,  893,  877,  321,  872,  154,  888,  891,
  878,  874,  879,  155,  156,  875,  157,  158,  159,  160,
  161,  892,  895,  321,  881,  898,  899,  880,  882,  903,
  321,  162,  883,  884,  885,  815,  904,  886,  816, 1104,
  163,  887,  164,  165,   23,  166,  889,  890,  167,  168,
  321,  905,  169,  908,  909,  910,  456,  911,  912,  817,
  913,  914,  915,  170,  923,  924,  925,  926,  927,  928,
  929,  818,  930,  931,  457,  932,  933,  934,  935,  321,
  458,  936,  171,  819,  937,  172,  938,  321,  820,  939,
  173,  940,  941,  942,  174,  175,  176,  177,  178,  943,
  821, 1495,  179,  180,  459,  460,  944,  822,  945,  461,
  946,  181,  947,  823,  948,  824,  642,  643,  949,  952,
  644,  974,  953,  462,  645,  954,  955,  321,  825,  956,
  463,  957,  958,  959, 1496,  960,  961,  963,  964,  646,
  647,  648,  182,  965,  183,  649, 1497,  966,  321,  204,
  464,  184,  967,  968,  969,  970,  185,  826,  971,  975,
  976,  186,  827, 1498,  650,  977,  978,  979,  651,  652,
 1499,  980,  981,  982,  983,  984, 1500,  985, 1501,  465,
  986,  987,  204,  988,  828,  989,  990,  466,  991,  992,
  993, 1502,  994,  995,  204,  996,  829,  997,  830,  831,
  653, 1344,  654,  832,  998,  467,  999, 1000, 1001, 1002,
 1003,  204, 1004, 1005,  468,  469,  655, 1006,  204, 1007,
 1008, 1009,  833, 1010,  204, 1503,  204, 1011, 1012, 1013,
 1014, 1037, 1059, 1060,   78, 1061, 1062, 1063,  656,  204,
 1064, 1504, 1065, 1066, 1067,   79, 1068,  470,  471, 1069,
 1070, 1071, 1072, 1073, 1074, 1080, 1081, 1082, 1083, 1505,
 1084, 1506, 1507, 1085, 1086,  834,   80,   81, 1088, 1089,
  657,  835,   82,  204,   83, 1090, 1092, 1091, 1345, 1093,
 1095, 1094,  836,  837,  658, 1508, 1097, 1109, 1096,  204,
 1098, 1099, 1100,  838,  659, 1101, 1103, 1102, 1111, 1105,
 1106, 1107, 1108, 1110,  472, 1112, 1113,  204, 1115,  204,
  204, 1114, 1346, 1116, 1117, 1120, 1121, 1122, 1123, 1124,
 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1347, 1509, 1132,
 1133,   84,   85,  204, 1134, 1135, 1136, 1137, 1138, 1139,
 1140,   86,   87, 1141, 1142, 1510, 1348, 1349, 1143, 1144,
 1145, 1147, 1350, 1351, 1352, 1353, 1511, 1148,  660, 1149,
 1150, 1151,   88,   89, 1152, 1153, 1354, 1154, 1155, 1156,
 1157, 1158,  661, 1159, 1160, 1162,  204, 1163, 1164,   90,
   91, 1170, 1167, 1168, 1169, 1171, 1172, 1015, 1173, 1174,
   92, 1175, 1176,  204, 1177, 1178, 1179, 1180, 1181,   93,
 1182, 1183, 1184, 1185,  204, 1016, 1017, 1018, 1019, 1020,
 1186, 1021, 1022, 1187, 1023, 1024, 1025, 1188, 1189, 1026,
 1190, 1192, 1194, 1446, 1197, 1196, 1191, 1200, 1206, 1027,
 1028, 1029, 1030, 1031, 1032, 1193, 1219, 1033, 1223, 1207,
 1034, 1447, 1448, 1449, 1450, 1451, 1195, 1452, 1453, 1230,
 1454, 1455, 1456, 1198, 1199, 1457, 1209, 1213, 1210, 1220,
 1240, 1241, 1211, 1224, 1242, 1458, 1459, 1460, 1461, 1462,
 1463, 1243, 1212, 1464, 1214, 1226, 1465, 1215, 1244, 1245,
 1227, 1259, 1260, 1228, 1265,   94,   95,   96, 1038, 1039,
 1040, 1041, 1042, 1235, 1043, 1044, 1266, 1045, 1046, 1047,
 1225, 1229, 1048, 1267, 1268, 1269, 1231, 1232, 1238, 1233,
 1234, 1236, 1049, 1050, 1051, 1052, 1053, 1054, 1237, 1239,
 1055, 1270, 1275, 1056, 1276, 1271, 1277, 1278, 1279, 1280,
 1281, 1282, 1283, 1284, 1285, 1286, 1287, 1290, 1295, 1296,
 1297, 1298, 1304, 1301, 1319, 1323, 1310, 1324, 1325, 1326,
 1312, 1327, 1316, 1342, 1343, 1357, 1300, 1302, 1358, 1303,
 1359, 1360, 1361, 1305, 1362, 1306, 1307, 1321, 1363, 1364,
 1365, 1308, 1366, 1309, 1367, 1368, 1369, 1311, 1370, 1313,
 1371, 1372, 1314, 1373, 1374, 1375, 1376, 1377, 1378, 1379,
 1380, 1381, 1386, 1382, 1315, 1387, 1317, 1318, 1320, 1388,
 1322, 1389, 1390, 1391, 1392, 1393, 1394, 1421, 1423, 1424,
 1425, 1426, 1427, 1432, 1428, 1433, 1434, 1435, 1436, 1437,
 1438, 1439, 1440, 1441, 1442, 1443, 1444, 1445, 1468, 1469,
 1470,  234,   26,   34,  281,  405,  530,  124,  565, 1519,
  525, 1166, 1520, 1521,  907,  341, 1491,  951,  780, 1488,
 1489, 1422, 1515, 1516,  897,  973,  902,  792, 1518, 1517,
 1490,  785,  686,  373, 1485, 1398, 1487, 1397,  761,  693,
 1486,  440,    0,  361,  549,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  869,
};
const short yycheck[] = {                                     347,
  348,  433,  125,  125,  125,  125,  354,  264,  256,  266,
  264,  125,  266,  125,  265,  125,  265,  125,  256,  256,
  125,  256,  125,  125,  281,  256,  256,  281,  285,  256,
  333,  285,  274,  275,   59,  123,  384,  123,  386,  123,
  125,  256,  256, 1075, 1076, 1077,  125,  454,  455,  276,
  256,   44,  400,   44,  291,   44,  125,  123,   44,  256,
  408,  123,  256,  305,  389,  302,   59,   44,   59,  123,
   59,  419,  420,   59,  422,   44,  268,  269,  270,  454,
  455,  323,   59,  431,  432,  123,  434,   44,  330,  123,
   59,  473,  474,  411,  309,   44,  411,   44,  355,   44,
  125,  355,   59,  428,  429,  430,  431,  432,  350,  125,
   59,  346,   59,  256,   59,  258,  346,  311,  312,  313,
  314,  315,  316,  317,  318,  340,  340,  123,  123,  123,
  411,  346,   59,  256,  256,  256,  256,  379,  376,  262,
  263,  378,  256,  266,  256,  387,  256,  378,  256,  123,
  273,  256,  123,  256,  256,  382,  123,  300,  123,  282,
  303,  125,  123,  286,  287,  413,   61,  361,  406,  123,
  293,  256,  378,  276,  297,  298,  299,  256,  301,  291,
  123,  378,  413,  413,  307,  427,  413,  256,  491,  258,
  302,  405,   61,   61,   44,  410,  444,  389,   61,  547,
   44,   61,  396,  326,  327,  456,  448,  456,  331,   59,
   61,  123,  291,  444,   61,   59,  339,  360,  340,   61,
  343,  344,  345,   61,  309,  348,  125,   44,  351,  352,
   61,  300,  346,   61,  303,  378,  346,   61,  444,  362,
  256,  498,   59,  259,  498,  368,  369,  444,  371,  372,
  373,  374,  375,  332,   44,  340,  504,  378,  378,  123,
  125,  346,  341,  386,  280,   61,  378,  125,  376,   59,
   61,   59,  395,  378,  397,  398,  292,  400,   61,  382,
  403,  404,  476,  405,  407,   61,   61,   61,  304,   61,
   61,  360,  256,  309,   61,  418,   61,   61,  406,  378,
   61,  380,  381,  413,   61,  321,  125,  504,  413,  378,
  413,  413,  328,   61,  437,   61,  510,  440,  334,   61,
  336,   61,  445,  444,  444,  410,  449,  450,  451,  452,
  453,   61,   61,  349,  457,  458,   61,   61,   61,  444,
   61,   61,  444,  466,  423,   61,  425,  311,  312,  313,
  314,  315,  316,  317,  318,   61,   61,  256,   59,  438,
  439,  504,  378,   61,   61,   61,   61,  383,   61,   61,
   61,  256,   61,   61,  497,   61,  499,   61,  277,  278,
   61,   61,   61,  506,  504,  284,   61,   61,  511,  405,
   61,  256,  257,  516,   61,  260,  349,  361,  256,  264,
   61,  417,  504,  419,  420,  484,   61,  755,  424,  267,
  295,   61,   61,   61,  279,  280,  281,   61,   61,   61,
  285,   61,   61,   61,   61,  310,   61,  443,   61,   61,
  288,  289,  396,  512,  513,  504,  294,  256,  296,  304,
   61,   61,   61,  308,  309,   61,   61,   61,  333,   61,
  335,   61,  337,  338,  256,  274,   61,  125,   61,   61,
   61,  280,   61,   61,   61,   61,  365,  366,  367,   61,
  486,  370,  357,  426,   61,  340,  492,  342,  123,  378,
  916,  917,  918,  919,  920,  304,  305,  503,  504,  291,
  309,  356,  391,  392,   61,  353,  354,   61,  514,   61,
   61,   61,   61,   61,  323,  363,  364,  460,   59,  408,
  409,  330,  476,  378,   61,   61,   61,  949,   61,   61,
   61,   61,  475,   61,   61,   61,  384,  385,   61,   61,
  332,  350,   61,  411,  433,  411,  411,   59,  454,  341,
  389,  494,  495,  401,  402,  410,  510,  500,  501,  502,
  503,  454,  505,  256,  412,  389,  259,  454,  454,  424,
  379,  514,  389,  421,  389,  454,  389,  389,  387,  434,
  454,  454,  454,  276,  454,  454,  378,  280,  380,  381,
  283,   59,   61,  454,  256,   61,  405,  290,  256,   59,
  411,  939,   61,   61,  389,  414,  415,  454,  411,  947,
  948,  454,  389,  306,  389,  277,  278,  411,  454,  454,
  389,  454,  284,  454,  454,  454,  319,  320,  411,  322,
  389,  423,  454,  425,  454,  411,  329,  295,  447,  448,
  389,  389,   61,  498,  389,  389,  438,  439,  389,  389,
  389,   61,  310,  454,  347,  454,  454,  512,  454,  507,
  508,  509,  389,  454,  454,  358,  454,  360,   59,  411,
  454,   61,  454,   61,   61,  333,   61,  335,   59,  337,
  338,  256,  454,  454,  377,   61,  454,  262,  263,   61,
   61,  266,  484,   59,  454,  504,   61,   61,  273,  357,
   61,  394,   61,  365,  366,  367,   61,  282,  370,   61,
   61,  286,  287,   61,   61,   61,  378,   61,  293,   61,
  512,  513,  297,  298,  299,   61,  301,   61,   61,  391,
  392,  411,  307,  426,  477,  478,  479,  480,  481,  482,
  483,   61,  435,  436,   61,  411,  408,  409,  441,  442,
  454,  326,  327,   59,  274,  275,  331,  411,  411,  411,
   59,  411,  411,  411,  339,  411,   59,  411,  343,  344,
  345,  433,   61,  348,  411,  411,  351,  352,   61,   61,
  411,  454,  454,   61,   59,  305,  454,  362,  389,   59,
  411,  454,  411,  368,  369,  454,  371,  372,  373,  374,
  375,   59,   61,  323,  411,   59,   61,  454,  411,   59,
  330,  386,  411,  411,  411,  256,   61,  411,  259,  389,
  395,  411,  397,  398,  517,  400,  411,  411,  403,  404,
  350,   61,  407,   59,   59,   59,  256,   59,   59,  280,
   59,   59,   59,  418,   59,   59,   59,   59,   59,   59,
   59,  292,   59,   59,  274,   59,   59,   59,   59,  379,
  280,   59,  437,  304,   61,  440,   61,  387,  309,   61,
  445,   61,   61,   61,  449,  450,  451,  452,  453,   61,
  321,  259,  457,  458,  304,  305,   61,  328,   61,  309,
   61,  466,   61,  334,   61,  336,  256,  257,   61,   59,
  260,  411,   61,  323,  264,   61,   61,  427,  349,   61,
  330,   61,   61,   61,  292,   61,   61,   61,   61,  279,
  280,  281,  497,   61,  499,  285,  304,   61,  448,  259,
  350,  506,   61,   61,   61,   61,  511,  378,   61,  411,
   59,  516,  383,  321,  304,   59,  411,  411,  308,  309,
  328,   61,   59,   59,   59,   59,  334,   59,  336,  379,
   59,   59,  292,   59,  405,   59,   59,  387,   59,   59,
   59,  349,   59,   59,  304,   59,  417,   59,  419,  420,
  340,  349,  342,  424,   59,  405,   59,   59,   59,   59,
   59,  321,   59,   59,  414,  415,  356,   59,  328,   59,
   59,   59,  443,   59,  334,  383,  336,   59,   59,   59,
   59,   59,   59,   59,  256,   59,   59,   59,  378,  349,
   59,  399,   59,   59,   59,  267,   59,  447,  448,   59,
   59,   59,   59,   59,   59,   59,   59,   59,   59,  417,
   59,  419,  420,   59,   61,  486,  288,  289,  454,   61,
  410,  492,  294,  383,  296,  411,   59,  411,  426,  454,
  454,  411,  503,  504,  424,  443,   61,   59,  454,  399,
  454,  454,  454,  514,  434,  454,  411,  454,   61,  411,
  411,  454,  411,  411,  504,  411,   59,  417,  411,  419,
  420,   61,  460,  411,  389,   59,   59,   59,   59,   59,
   59,   59,   59,   59,   59,   59,   59,  475,  486,   59,
   59,  353,  354,  443,   59,   59,   59,   59,   59,   59,
   59,  363,  364,   59,   61,  503,  494,  495,   61,   61,
   61,   61,  500,  501,  502,  503,  514,   61,  498,   61,
   61,   61,  384,  385,   61,   61,  514,   61,   61,   61,
   61,   61,  512,   61,   61,   61,  486,   61,   61,  401,
  402,   59,  411,  411,  411,   59,   59,  443,   59,   59,
  412,   59,   59,  503,   59,   59,   59,   59,   59,  421,
   59,   59,   59,   59,  514,  461,  462,  463,  464,  465,
   59,  467,  468,   59,  470,  471,  472,   59,   59,  475,
   59,   61,   59,  443,   59,   61,  411,   59,  389,  485,
  486,  487,  488,  489,  490,  411,   59,  493,  454,  389,
  496,  461,  462,  463,  464,  465,  411,  467,  468,   61,
  470,  471,  472,  411,  411,  475,  389,  411,  389,  411,
   59,   59,  389,  411,   59,  485,  486,  487,  488,  489,
  490,   59,  389,  493,  389,  454,  496,  389,   59,  416,
  454,   59,   59,  454,   59,  507,  508,  509,  461,  462,
  463,  464,  465,  389,  467,  468,   59,  470,  471,  472,
  411,  411,  475,   59,   59,   59,  411,  411,  454,  411,
  411,  411,  485,  486,  487,  488,  489,  490,  411,  411,
  493,   59,   59,  496,   59,  388,   59,   59,   59,   59,
   59,   59,   59,   59,   59,   59,  416,   59,   59,   59,
  459,   44,   61,  411,   61,   59,  411,   59,   59,   59,
  411,   59,  411,   59,   59,   59,  454,  454,   59,  454,
   59,   59,   59,  454,   59,  454,  454,  411,   59,   59,
   59,  454,   59,  454,   59,   59,   59,  454,   59,  454,
   59,   59,  454,   59,   59,   59,   59,   59,   59,   59,
   59,   59,   59,  388,  454,   59,  454,  454,  454,   59,
  454,   59,   59,   59,   59,   59,   59,  389,   59,   59,
   59,   59,   59,   59,  388,   59,   59,   59,   59,   59,
   59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
   59,  123,   59,   59,   59,  123,  279,  123,  318, 1492,
  262,  839, 1494, 1514,  585,   73, 1420,  627,  473, 1403,
 1405, 1298, 1472, 1474,  570,  662,  578,  505, 1477, 1475,
 1418,  495,  367,  126, 1396, 1251, 1402, 1249,  448,  378,
 1400,  187,   -1,   97,  295,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  536,
};
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 517
#if YYDEBUG
const char * const yyname[] = {
"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,"','",0,0,0,0,0,0,0,0,0,0,0,0,0,0,"';'",0,"'='",0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
"ACCEPT_PASSWORD","ACTION","ADMIN","AFTYPE","T_ALLOW","ANTI_NICK_FLOOD",
"ANTI_SPAM_EXIT_MESSAGE_TIME","AUTOCONN","T_BLOCK","BURST_AWAY",
"BURST_TOPICWHO","BYTES","KBYTES","MBYTES","GBYTES","TBYTES","CALLER_ID_WAIT",
"CAN_FLOOD","CAN_IDLE","CHANNEL","CIDR_BITLEN_IPV4","CIDR_BITLEN_IPV6",
"CIPHER_PREFERENCE","CLASS","COMPRESSED","COMPRESSION_LEVEL","CONNECT",
"CONNECTFREQ","CRYPTLINK","DEFAULT_CIPHER_PREFERENCE","DEFAULT_FLOODCOUNT",
"DEFAULT_SPLIT_SERVER_COUNT","DEFAULT_SPLIT_USER_COUNT","DENY","DESCRIPTION",
"DIE","DISABLE_AUTH","DISABLE_FAKE_CHANNELS","DISABLE_HIDDEN",
"DISABLE_LOCAL_CHANNELS","DISABLE_REMOTE_COMMANDS","DOT_IN_IP6_ADDR",
"DOTS_IN_IDENT","DURATION","EGDPOOL_PATH","EMAIL","ENABLE","ENCRYPTED",
"EXCEED_LIMIT","EXEMPT","FAILED_OPER_NOTICE","FAKENAME","IRCD_FLAGS",
"FLATTEN_LINKS","FFAILED_OPERLOG","FKILLLOG","FKLINELOG","FGLINELOG",
"FIOERRLOG","FOPERLOG","FOPERSPYLOG","FUSERLOG","GECOS","GENERAL","GLINE",
"GLINES","GLINE_EXEMPT","GLINE_LOG","GLINE_TIME","GLINE_MIN_CIDR",
"GLINE_MIN_CIDR6","GLOBAL_KILL","IRCD_AUTH","NEED_IDENT","HAVENT_READ_CONF",
"HELP_CHANNEL","HIDDEN","HIDDEN_ADMIN","HIDDEN_NAME","HIDDEN_OPER",
"HIDE_SERVER_IPS","HIDE_SERVERS","HIDE_SPOOF_IPS","HOST","HUB","HUB_MASK",
"IDLETIME","IGNORE_BOGUS_TS","INVISIBLE_ON_CONNECT","IP","KILL",
"KILL_CHASE_TIME_LIMIT","KLINE","KLINE_EXEMPT","KLINE_REASON",
"KLINE_WITH_REASON","KNOCK_DELAY","KNOCK_DELAY_CHANNEL","LAZYLINK","LEAF_MASK",
"LINKS_DELAY","LISTEN","T_LOG","LOGGING","LOG_LEVEL","MAX_ACCEPT","MAX_BANS",
"MAX_CHANS_PER_USER","MAX_GLOBAL","MAX_IDENT","MAX_LOCAL","MAX_NICK_CHANGES",
"MAX_NICK_TIME","MAX_NUMBER","MAX_TARGETS","MESSAGE_LOCALE","MIN_NONWILDCARD",
"MIN_NONWILDCARD_SIMPLE","MODE_Z","MODULE","MODULES","NAME","NEED_PASSWORD",
"NETWORK_DESC","NETWORK_NAME","NICK","NICK_CHANGES","NO_CREATE_ON_SPLIT",
"NO_JOIN_ON_SPLIT","NO_OPER_FLOOD","NO_TILDE","NOT","NUMBER","NUMBER_PER_IDENT",
"NUMBER_PER_CIDR","NUMBER_PER_IP","NUMBER_PER_IP_GLOBAL","OPERATOR",
"OPERS_BYPASS_CALLERID","OPER_LOG","OPER_ONLY_UMODES","OPER_PASS_RESV",
"OPER_SPY_T","OPER_UMODES","JOIN_FLOOD_COUNT","JOIN_FLOOD_TIME","PACE_WAIT",
"PACE_WAIT_SIMPLE","PASSWORD","PATH","PING_COOKIE","PING_TIME","PING_WARNING",
"PORT","QSTRING","QUIET_ON_BAN","REASON","REDIRPORT","REDIRSERV","REGEX_T",
"REHASH","TREJECT_HOLD_TIME","REMOTE","REMOTEBAN","RESTRICT_CHANNELS",
"RESTRICTED","RSA_PRIVATE_KEY_FILE","RSA_PUBLIC_KEY_FILE",
"SSL_CERTIFICATE_FILE","RESV","RESV_EXEMPT","SECONDS","MINUTES","HOURS","DAYS",
"WEEKS","SENDQ","SEND_PASSWORD","SERVERHIDE","SERVERINFO","SERVLINK_PATH",
"SERVICES_NAME","IRCD_SID","TKLINE_EXPIRE_NOTICES","T_SHARED","T_CLUSTER",
"T_SNOOP","TYPE","SHORT_MOTD","SILENT","SPOOF","SPOOF_NOTICE",
"STATS_E_DISABLED","STATS_I_OPER_ONLY","STATS_K_OPER_ONLY","STATS_O_OPER_ONLY",
"STATS_P_OPER_ONLY","TBOOL","TMASKED","T_REJECT","TS_MAX_DELTA","TS_WARN_DELTA",
"TWODOTS","T_ALL","T_BOTS","T_SOFTCALLERID","T_CALLERID","T_CCONN",
"T_CCONN_FULL","T_CLIENT_FLOOD","T_DEAF","T_DEBUG","T_DRONE","T_EXTERNAL",
"T_FULL","T_INVISIBLE","T_IPV4","T_IPV6","T_LOCOPS","T_LOGPATH","T_L_CRIT",
"T_L_DEBUG","T_L_ERROR","T_L_INFO","T_L_NOTICE","T_L_TRACE","T_L_WARN",
"T_MAX_CLIENTS","T_NCHANGE","T_OPERWALL","T_REJ","T_SERVNOTICE","T_SKILL",
"T_SPY","T_SSL","T_UMODES","T_UNAUTH","T_UNRESV","T_UNXLINE","T_WALLOP",
"THROTTLE_TIME","TOPICBURST","TRUE_NO_OPER_FLOOD","TKLINE","TXLINE","TRESV",
"UNKLINE","USER","T_USERMODE","USE_EGD","USE_EXCEPT","USE_INVEX","USE_KNOCK",
"USE_LOGGING","USE_WHOIS_ACTUALLY","VHOST","VHOST6","XLINE","WARN",
"WARN_NO_NLINE","WEBIRC",
};
const char * const yyrule[] = {
"$accept : conf",
"conf :",
"conf : conf conf_item",
"conf_item : admin_entry",
"conf_item : logging_entry",
"conf_item : oper_entry",
"conf_item : channel_entry",
"conf_item : class_entry",
"conf_item : listen_entry",
"conf_item : auth_entry",
"conf_item : serverinfo_entry",
"conf_item : serverhide_entry",
"conf_item : resv_entry",
"conf_item : shared_entry",
"conf_item : cluster_entry",
"conf_item : connect_entry",
"conf_item : kill_entry",
"conf_item : deny_entry",
"conf_item : exempt_entry",
"conf_item : general_entry",
"conf_item : gline_entry",
"conf_item : gecos_entry",
"conf_item : modules_entry",
"conf_item : webirc_entry",
"conf_item : error ';'",
"conf_item : error '}'",
"timespec_ :",
"timespec_ : timespec",
"timespec : NUMBER timespec_",
"timespec : NUMBER SECONDS timespec_",
"timespec : NUMBER MINUTES timespec_",
"timespec : NUMBER HOURS timespec_",
"timespec : NUMBER DAYS timespec_",
"timespec : NUMBER WEEKS timespec_",
"sizespec_ :",
"sizespec_ : sizespec",
"sizespec : NUMBER sizespec_",
"sizespec : NUMBER BYTES sizespec_",
"sizespec : NUMBER KBYTES sizespec_",
"sizespec : NUMBER MBYTES sizespec_",
"modules_entry : MODULES '{' modules_items '}' ';'",
"modules_items : modules_items modules_item",
"modules_items : modules_item",
"modules_item : modules_module",
"modules_item : modules_path",
"modules_item : error ';'",
"modules_module : MODULE '=' QSTRING ';'",
"modules_path : PATH '=' QSTRING ';'",
"serverinfo_entry : SERVERINFO '{' serverinfo_items '}' ';'",
"serverinfo_items : serverinfo_items serverinfo_item",
"serverinfo_items : serverinfo_item",
"serverinfo_item : serverinfo_name",
"serverinfo_item : serverinfo_vhost",
"serverinfo_item : serverinfo_hub",
"serverinfo_item : serverinfo_description",
"serverinfo_item : serverinfo_network_name",
"serverinfo_item : serverinfo_network_desc",
"serverinfo_item : serverinfo_services_name",
"serverinfo_item : serverinfo_help_channel",
"serverinfo_item : serverinfo_max_clients",
"serverinfo_item : serverinfo_rsa_private_key_file",
"serverinfo_item : serverinfo_vhost6",
"serverinfo_item : serverinfo_sid",
"serverinfo_item : serverinfo_ssl_certificate_file",
"serverinfo_item : error ';'",
"serverinfo_ssl_certificate_file : SSL_CERTIFICATE_FILE '=' QSTRING ';'",
"serverinfo_rsa_private_key_file : RSA_PRIVATE_KEY_FILE '=' QSTRING ';'",
"serverinfo_name : NAME '=' QSTRING ';'",
"serverinfo_sid : IRCD_SID '=' QSTRING ';'",
"serverinfo_description : DESCRIPTION '=' QSTRING ';'",
"serverinfo_network_name : NETWORK_NAME '=' QSTRING ';'",
"serverinfo_network_desc : NETWORK_DESC '=' QSTRING ';'",
"serverinfo_services_name : SERVICES_NAME '=' QSTRING ';'",
"serverinfo_help_channel : HELP_CHANNEL '=' QSTRING ';'",
"serverinfo_vhost : VHOST '=' QSTRING ';'",
"serverinfo_vhost6 : VHOST6 '=' QSTRING ';'",
"serverinfo_max_clients : T_MAX_CLIENTS '=' NUMBER ';'",
"serverinfo_hub : HUB '=' TBOOL ';'",
"admin_entry : ADMIN '{' admin_items '}' ';'",
"admin_items : admin_items admin_item",
"admin_items : admin_item",
"admin_item : admin_name",
"admin_item : admin_description",
"admin_item : admin_email",
"admin_item : error ';'",
"admin_name : NAME '=' QSTRING ';'",
"admin_email : EMAIL '=' QSTRING ';'",
"admin_description : DESCRIPTION '=' QSTRING ';'",
"logging_entry : LOGGING '{' logging_items '}' ';'",
"logging_items : logging_items logging_item",
"logging_items : logging_item",
"logging_item : logging_path",
"logging_item : logging_oper_log",
"logging_item : logging_log_level",
"logging_item : logging_use_logging",
"logging_item : logging_fuserlog",
"logging_item : logging_foperlog",
"logging_item : logging_fglinelog",
"logging_item : logging_fklinelog",
"logging_item : logging_killlog",
"logging_item : logging_foperspylog",
"logging_item : logging_ioerrlog",
"logging_item : logging_ffailed_operlog",
"logging_item : error ';'",
"logging_path : T_LOGPATH '=' QSTRING ';'",
"logging_oper_log : OPER_LOG '=' QSTRING ';'",
"logging_fuserlog : FUSERLOG '=' QSTRING ';'",
"logging_ffailed_operlog : FFAILED_OPERLOG '=' QSTRING ';'",
"logging_foperlog : FOPERLOG '=' QSTRING ';'",
"logging_foperspylog : FOPERSPYLOG '=' QSTRING ';'",
"logging_fglinelog : FGLINELOG '=' QSTRING ';'",
"logging_fklinelog : FKLINELOG '=' QSTRING ';'",
"logging_ioerrlog : FIOERRLOG '=' QSTRING ';'",
"logging_killlog : FKILLLOG '=' QSTRING ';'",
"logging_log_level : LOG_LEVEL '=' T_L_CRIT ';'",
"logging_log_level : LOG_LEVEL '=' T_L_ERROR ';'",
"logging_log_level : LOG_LEVEL '=' T_L_WARN ';'",
"logging_log_level : LOG_LEVEL '=' T_L_NOTICE ';'",
"logging_log_level : LOG_LEVEL '=' T_L_TRACE ';'",
"logging_log_level : LOG_LEVEL '=' T_L_INFO ';'",
"logging_log_level : LOG_LEVEL '=' T_L_DEBUG ';'",
"logging_use_logging : USE_LOGGING '=' TBOOL ';'",
"$$1 :",
"oper_entry : OPERATOR $$1 oper_name_b '{' oper_items '}' ';'",
"oper_name_b :",
"oper_name_b : oper_name_t",
"oper_items : oper_items oper_item",
"oper_items : oper_item",
"oper_item : oper_name",
"oper_item : oper_user",
"oper_item : oper_password",
"oper_item : oper_hidden_admin",
"oper_item : oper_hidden_oper",
"oper_item : oper_umodes",
"oper_item : oper_class",
"oper_item : oper_global_kill",
"oper_item : oper_remote",
"oper_item : oper_kline",
"oper_item : oper_xline",
"oper_item : oper_unkline",
"oper_item : oper_gline",
"oper_item : oper_nick_changes",
"oper_item : oper_remoteban",
"oper_item : oper_die",
"oper_item : oper_rehash",
"oper_item : oper_admin",
"oper_item : oper_operwall",
"oper_item : oper_snoop",
"oper_item : oper_encrypted",
"oper_item : oper_rsa_public_key_file",
"oper_item : oper_flags",
"oper_item : error ';'",
"oper_name : NAME '=' QSTRING ';'",
"oper_name_t : QSTRING",
"oper_user : USER '=' QSTRING ';'",
"oper_password : PASSWORD '=' QSTRING ';'",
"oper_encrypted : ENCRYPTED '=' TBOOL ';'",
"oper_rsa_public_key_file : RSA_PUBLIC_KEY_FILE '=' QSTRING ';'",
"oper_class : CLASS '=' QSTRING ';'",
"$$2 :",
"oper_umodes : T_UMODES $$2 '=' oper_umodes_items ';'",
"oper_umodes_items : oper_umodes_items ',' oper_umodes_item",
"oper_umodes_items : oper_umodes_item",
"oper_umodes_item : T_BOTS",
"oper_umodes_item : T_CCONN",
"oper_umodes_item : T_CCONN_FULL",
"oper_umodes_item : T_DEAF",
"oper_umodes_item : T_DEBUG",
"oper_umodes_item : T_FULL",
"oper_umodes_item : T_SKILL",
"oper_umodes_item : T_NCHANGE",
"oper_umodes_item : T_REJ",
"oper_umodes_item : T_UNAUTH",
"oper_umodes_item : T_SPY",
"oper_umodes_item : T_EXTERNAL",
"oper_umodes_item : T_OPERWALL",
"oper_umodes_item : T_SERVNOTICE",
"oper_umodes_item : T_INVISIBLE",
"oper_umodes_item : T_WALLOP",
"oper_umodes_item : T_SOFTCALLERID",
"oper_umodes_item : T_CALLERID",
"oper_umodes_item : T_LOCOPS",
"oper_umodes_item : T_SNOOP",
"oper_global_kill : GLOBAL_KILL '=' TBOOL ';'",
"oper_remote : REMOTE '=' TBOOL ';'",
"oper_remoteban : REMOTEBAN '=' TBOOL ';'",
"oper_kline : KLINE '=' TBOOL ';'",
"oper_xline : XLINE '=' TBOOL ';'",
"oper_unkline : UNKLINE '=' TBOOL ';'",
"oper_gline : GLINE '=' TBOOL ';'",
"oper_nick_changes : NICK_CHANGES '=' TBOOL ';'",
"oper_die : DIE '=' TBOOL ';'",
"oper_rehash : REHASH '=' TBOOL ';'",
"oper_admin : ADMIN '=' TBOOL ';'",
"oper_hidden_admin : HIDDEN_ADMIN '=' TBOOL ';'",
"oper_hidden_oper : HIDDEN_OPER '=' TBOOL ';'",
"oper_operwall : T_OPERWALL '=' TBOOL ';'",
"oper_snoop : T_SNOOP '=' TBOOL ';'",
"$$3 :",
"oper_flags : IRCD_FLAGS $$3 '=' oper_flags_items ';'",
"oper_flags_items : oper_flags_items ',' oper_flags_item",
"oper_flags_items : oper_flags_item",
"$$4 :",
"oper_flags_item : NOT $$4 oper_flags_item_atom",
"$$5 :",
"oper_flags_item : $$5 oper_flags_item_atom",
"oper_flags_item_atom : GLOBAL_KILL",
"oper_flags_item_atom : REMOTE",
"oper_flags_item_atom : KLINE",
"oper_flags_item_atom : UNKLINE",
"oper_flags_item_atom : XLINE",
"oper_flags_item_atom : GLINE",
"oper_flags_item_atom : DIE",
"oper_flags_item_atom : REHASH",
"oper_flags_item_atom : ADMIN",
"oper_flags_item_atom : HIDDEN_ADMIN",
"oper_flags_item_atom : NICK_CHANGES",
"oper_flags_item_atom : T_OPERWALL",
"oper_flags_item_atom : OPER_SPY_T",
"oper_flags_item_atom : HIDDEN_OPER",
"oper_flags_item_atom : REMOTEBAN",
"oper_flags_item_atom : ENCRYPTED",
"oper_flags_item_atom : T_SNOOP",
"$$6 :",
"webirc_entry : WEBIRC $$6 '{' webirc_items '}' ';'",
"webirc_items : webirc_items webirc_item",
"webirc_items : webirc_item",
"webirc_item : webirc_host",
"webirc_item : webirc_passwd",
"webirc_item : error ';'",
"webirc_host : HOST '=' QSTRING ';'",
"webirc_passwd : PASSWORD '=' QSTRING ';'",
"$$7 :",
"class_entry : CLASS $$7 class_name_b '{' class_items '}' ';'",
"class_name_b :",
"class_name_b : class_name_t",
"class_items : class_items class_item",
"class_items : class_item",
"class_item : class_name",
"class_item : class_cidr_bitlen_ipv4",
"class_item : class_cidr_bitlen_ipv6",
"class_item : class_ping_time",
"class_item : class_ping_warning",
"class_item : class_number_per_cidr",
"class_item : class_number_per_ip",
"class_item : class_connectfreq",
"class_item : class_max_number",
"class_item : class_max_global",
"class_item : class_max_local",
"class_item : class_max_ident",
"class_item : class_sendq",
"class_item : error ';'",
"class_name : NAME '=' QSTRING ';'",
"class_name_t : QSTRING",
"class_ping_time : PING_TIME '=' timespec ';'",
"class_ping_warning : PING_WARNING '=' timespec ';'",
"class_number_per_ip : NUMBER_PER_IP '=' NUMBER ';'",
"class_connectfreq : CONNECTFREQ '=' timespec ';'",
"class_max_number : MAX_NUMBER '=' NUMBER ';'",
"class_max_global : MAX_GLOBAL '=' NUMBER ';'",
"class_max_local : MAX_LOCAL '=' NUMBER ';'",
"class_max_ident : MAX_IDENT '=' NUMBER ';'",
"class_sendq : SENDQ '=' sizespec ';'",
"class_cidr_bitlen_ipv4 : CIDR_BITLEN_IPV4 '=' NUMBER ';'",
"class_cidr_bitlen_ipv6 : CIDR_BITLEN_IPV6 '=' NUMBER ';'",
"class_number_per_cidr : NUMBER_PER_CIDR '=' NUMBER ';'",
"$$8 :",
"listen_entry : LISTEN $$8 '{' listen_items '}' ';'",
"$$9 :",
"listen_flags : IRCD_FLAGS $$9 '=' listen_flags_items ';'",
"listen_flags_items : listen_flags_items ',' listen_flags_item",
"listen_flags_items : listen_flags_item",
"listen_flags_item : T_SSL",
"listen_flags_item : HIDDEN",
"listen_items : listen_items listen_item",
"listen_items : listen_item",
"listen_item : listen_port",
"listen_item : listen_flags",
"listen_item : listen_address",
"listen_item : listen_host",
"listen_item : error ';'",
"$$10 :",
"listen_port : PORT '=' port_items $$10 ';'",
"port_items : port_items ',' port_item",
"port_items : port_item",
"port_item : NUMBER",
"port_item : NUMBER TWODOTS NUMBER",
"listen_address : IP '=' QSTRING ';'",
"listen_host : HOST '=' QSTRING ';'",
"$$11 :",
"auth_entry : IRCD_AUTH $$11 '{' auth_items '}' ';'",
"auth_items : auth_items auth_item",
"auth_items : auth_item",
"auth_item : auth_user",
"auth_item : auth_passwd",
"auth_item : auth_class",
"auth_item : auth_flags",
"auth_item : auth_kline_exempt",
"auth_item : auth_need_ident",
"auth_item : auth_exceed_limit",
"auth_item : auth_no_tilde",
"auth_item : auth_gline_exempt",
"auth_item : auth_spoof",
"auth_item : auth_spoof_notice",
"auth_item : auth_redir_serv",
"auth_item : auth_redir_port",
"auth_item : auth_can_flood",
"auth_item : auth_need_password",
"auth_item : auth_encrypted",
"auth_item : error ';'",
"auth_user : USER '=' QSTRING ';'",
"auth_passwd : PASSWORD '=' QSTRING ';'",
"auth_spoof_notice : SPOOF_NOTICE '=' TBOOL ';'",
"auth_class : CLASS '=' QSTRING ';'",
"auth_encrypted : ENCRYPTED '=' TBOOL ';'",
"$$12 :",
"auth_flags : IRCD_FLAGS $$12 '=' auth_flags_items ';'",
"auth_flags_items : auth_flags_items ',' auth_flags_item",
"auth_flags_items : auth_flags_item",
"$$13 :",
"auth_flags_item : NOT $$13 auth_flags_item_atom",
"$$14 :",
"auth_flags_item : $$14 auth_flags_item_atom",
"auth_flags_item_atom : SPOOF_NOTICE",
"auth_flags_item_atom : EXCEED_LIMIT",
"auth_flags_item_atom : KLINE_EXEMPT",
"auth_flags_item_atom : NEED_IDENT",
"auth_flags_item_atom : CAN_FLOOD",
"auth_flags_item_atom : CAN_IDLE",
"auth_flags_item_atom : NO_TILDE",
"auth_flags_item_atom : GLINE_EXEMPT",
"auth_flags_item_atom : RESV_EXEMPT",
"auth_flags_item_atom : NEED_PASSWORD",
"auth_kline_exempt : KLINE_EXEMPT '=' TBOOL ';'",
"auth_need_ident : NEED_IDENT '=' TBOOL ';'",
"auth_exceed_limit : EXCEED_LIMIT '=' TBOOL ';'",
"auth_can_flood : CAN_FLOOD '=' TBOOL ';'",
"auth_no_tilde : NO_TILDE '=' TBOOL ';'",
"auth_gline_exempt : GLINE_EXEMPT '=' TBOOL ';'",
"auth_spoof : SPOOF '=' QSTRING ';'",
"auth_redir_serv : REDIRSERV '=' QSTRING ';'",
"auth_redir_port : REDIRPORT '=' NUMBER ';'",
"auth_need_password : NEED_PASSWORD '=' TBOOL ';'",
"$$15 :",
"resv_entry : RESV $$15 '{' resv_items '}' ';'",
"resv_items : resv_items resv_item",
"resv_items : resv_item",
"resv_item : resv_creason",
"resv_item : resv_channel",
"resv_item : resv_nick",
"resv_item : error ';'",
"resv_creason : REASON '=' QSTRING ';'",
"resv_channel : CHANNEL '=' QSTRING ';'",
"resv_nick : NICK '=' QSTRING ';'",
"$$16 :",
"shared_entry : T_SHARED $$16 '{' shared_items '}' ';'",
"shared_items : shared_items shared_item",
"shared_items : shared_item",
"shared_item : shared_name",
"shared_item : shared_user",
"shared_item : shared_type",
"shared_item : error ';'",
"shared_name : NAME '=' QSTRING ';'",
"shared_user : USER '=' QSTRING ';'",
"$$17 :",
"shared_type : TYPE $$17 '=' shared_types ';'",
"shared_types : shared_types ',' shared_type_item",
"shared_types : shared_type_item",
"shared_type_item : KLINE",
"shared_type_item : TKLINE",
"shared_type_item : UNKLINE",
"shared_type_item : XLINE",
"shared_type_item : TXLINE",
"shared_type_item : T_UNXLINE",
"shared_type_item : RESV",
"shared_type_item : TRESV",
"shared_type_item : T_UNRESV",
"shared_type_item : T_LOCOPS",
"shared_type_item : T_USERMODE",
"shared_type_item : T_ALL",
"$$18 :",
"cluster_entry : T_CLUSTER $$18 '{' cluster_items '}' ';'",
"cluster_items : cluster_items cluster_item",
"cluster_items : cluster_item",
"cluster_item : cluster_name",
"cluster_item : cluster_type",
"cluster_item : error ';'",
"cluster_name : NAME '=' QSTRING ';'",
"$$19 :",
"cluster_type : TYPE $$19 '=' cluster_types ';'",
"cluster_types : cluster_types ',' cluster_type_item",
"cluster_types : cluster_type_item",
"cluster_type_item : KLINE",
"cluster_type_item : TKLINE",
"cluster_type_item : UNKLINE",
"cluster_type_item : XLINE",
"cluster_type_item : TXLINE",
"cluster_type_item : T_UNXLINE",
"cluster_type_item : RESV",
"cluster_type_item : TRESV",
"cluster_type_item : T_UNRESV",
"cluster_type_item : T_LOCOPS",
"cluster_type_item : T_ALL",
"$$20 :",
"connect_entry : CONNECT $$20 connect_name_b '{' connect_items '}' ';'",
"connect_name_b :",
"connect_name_b : connect_name_t",
"connect_items : connect_items connect_item",
"connect_items : connect_item",
"connect_item : connect_name",
"connect_item : connect_host",
"connect_item : connect_vhost",
"connect_item : connect_send_password",
"connect_item : connect_accept_password",
"connect_item : connect_aftype",
"connect_item : connect_port",
"connect_item : connect_fakename",
"connect_item : connect_flags",
"connect_item : connect_hub_mask",
"connect_item : connect_leaf_mask",
"connect_item : connect_class",
"connect_item : connect_auto",
"connect_item : connect_encrypted",
"connect_item : connect_compressed",
"connect_item : connect_cryptlink",
"connect_item : connect_rsa_public_key_file",
"connect_item : connect_cipher_preference",
"connect_item : connect_topicburst",
"connect_item : error ';'",
"connect_name : NAME '=' QSTRING ';'",
"connect_name_t : QSTRING",
"connect_host : HOST '=' QSTRING ';'",
"connect_vhost : VHOST '=' QSTRING ';'",
"connect_send_password : SEND_PASSWORD '=' QSTRING ';'",
"connect_accept_password : ACCEPT_PASSWORD '=' QSTRING ';'",
"connect_port : PORT '=' NUMBER ';'",
"connect_aftype : AFTYPE '=' T_IPV4 ';'",
"connect_aftype : AFTYPE '=' T_IPV6 ';'",
"connect_fakename : FAKENAME '=' QSTRING ';'",
"$$21 :",
"connect_flags : IRCD_FLAGS $$21 '=' connect_flags_items ';'",
"connect_flags_items : connect_flags_items ',' connect_flags_item",
"connect_flags_items : connect_flags_item",
"$$22 :",
"connect_flags_item : NOT $$22 connect_flags_item_atom",
"$$23 :",
"connect_flags_item : $$23 connect_flags_item_atom",
"connect_flags_item_atom : LAZYLINK",
"connect_flags_item_atom : COMPRESSED",
"connect_flags_item_atom : CRYPTLINK",
"connect_flags_item_atom : AUTOCONN",
"connect_flags_item_atom : BURST_AWAY",
"connect_flags_item_atom : TOPICBURST",
"connect_rsa_public_key_file : RSA_PUBLIC_KEY_FILE '=' QSTRING ';'",
"connect_encrypted : ENCRYPTED '=' TBOOL ';'",
"connect_cryptlink : CRYPTLINK '=' TBOOL ';'",
"connect_compressed : COMPRESSED '=' TBOOL ';'",
"connect_auto : AUTOCONN '=' TBOOL ';'",
"connect_topicburst : TOPICBURST '=' TBOOL ';'",
"connect_hub_mask : HUB_MASK '=' QSTRING ';'",
"connect_leaf_mask : LEAF_MASK '=' QSTRING ';'",
"connect_class : CLASS '=' QSTRING ';'",
"connect_cipher_preference : CIPHER_PREFERENCE '=' QSTRING ';'",
"$$24 :",
"kill_entry : KILL $$24 '{' kill_items '}' ';'",
"$$25 :",
"kill_type : TYPE $$25 '=' kill_type_items ';'",
"kill_type_items : kill_type_items ',' kill_type_item",
"kill_type_items : kill_type_item",
"kill_type_item : REGEX_T",
"kill_items : kill_items kill_item",
"kill_items : kill_item",
"kill_item : kill_user",
"kill_item : kill_reason",
"kill_item : kill_type",
"kill_item : error",
"kill_user : USER '=' QSTRING ';'",
"kill_reason : REASON '=' QSTRING ';'",
"$$26 :",
"deny_entry : DENY $$26 '{' deny_items '}' ';'",
"deny_items : deny_items deny_item",
"deny_items : deny_item",
"deny_item : deny_ip",
"deny_item : deny_reason",
"deny_item : error",
"deny_ip : IP '=' QSTRING ';'",
"deny_reason : REASON '=' QSTRING ';'",
"exempt_entry : EXEMPT '{' exempt_items '}' ';'",
"exempt_items : exempt_items exempt_item",
"exempt_items : exempt_item",
"exempt_item : exempt_ip",
"exempt_item : error",
"exempt_ip : IP '=' QSTRING ';'",
"$$27 :",
"gecos_entry : GECOS $$27 '{' gecos_items '}' ';'",
"$$28 :",
"gecos_flags : TYPE $$28 '=' gecos_flags_items ';'",
"gecos_flags_items : gecos_flags_items ',' gecos_flags_item",
"gecos_flags_items : gecos_flags_item",
"gecos_flags_item : REGEX_T",
"gecos_items : gecos_items gecos_item",
"gecos_items : gecos_item",
"gecos_item : gecos_name",
"gecos_item : gecos_reason",
"gecos_item : gecos_flags",
"gecos_item : error",
"gecos_name : NAME '=' QSTRING ';'",
"gecos_reason : REASON '=' QSTRING ';'",
"general_entry : GENERAL '{' general_items '}' ';'",
"general_items : general_items general_item",
"general_items : general_item",
"general_item : general_hide_spoof_ips",
"general_item : general_ignore_bogus_ts",
"general_item : general_failed_oper_notice",
"general_item : general_anti_nick_flood",
"general_item : general_max_nick_time",
"general_item : general_max_nick_changes",
"general_item : general_max_accept",
"general_item : general_anti_spam_exit_message_time",
"general_item : general_ts_warn_delta",
"general_item : general_ts_max_delta",
"general_item : general_kill_chase_time_limit",
"general_item : general_kline_with_reason",
"general_item : general_kline_reason",
"general_item : general_invisible_on_connect",
"general_item : general_mode_z",
"general_item : general_warn_no_nline",
"general_item : general_dots_in_ident",
"general_item : general_stats_o_oper_only",
"general_item : general_stats_k_oper_only",
"general_item : general_pace_wait",
"general_item : general_stats_i_oper_only",
"general_item : general_pace_wait_simple",
"general_item : general_stats_P_oper_only",
"general_item : general_short_motd",
"general_item : general_no_oper_flood",
"general_item : general_true_no_oper_flood",
"general_item : general_oper_pass_resv",
"general_item : general_idletime",
"general_item : general_message_locale",
"general_item : general_oper_only_umodes",
"general_item : general_max_targets",
"general_item : general_use_egd",
"general_item : general_egdpool_path",
"general_item : general_oper_umodes",
"general_item : general_caller_id_wait",
"general_item : general_opers_bypass_callerid",
"general_item : general_default_floodcount",
"general_item : general_min_nonwildcard",
"general_item : general_min_nonwildcard_simple",
"general_item : general_servlink_path",
"general_item : general_disable_remote_commands",
"general_item : general_default_cipher_preference",
"general_item : general_compression_level",
"general_item : general_client_flood",
"general_item : general_throttle_time",
"general_item : general_havent_read_conf",
"general_item : general_dot_in_ip6_addr",
"general_item : general_ping_cookie",
"general_item : general_disable_auth",
"general_item : general_burst_away",
"general_item : general_tkline_expire_notices",
"general_item : general_gline_min_cidr",
"general_item : general_gline_min_cidr6",
"general_item : general_use_whois_actually",
"general_item : general_reject_hold_time",
"general_item : general_stats_e_disabled",
"general_item : error",
"general_gline_min_cidr : GLINE_MIN_CIDR '=' NUMBER ';'",
"general_gline_min_cidr6 : GLINE_MIN_CIDR6 '=' NUMBER ';'",
"general_burst_away : BURST_AWAY '=' TBOOL ';'",
"general_use_whois_actually : USE_WHOIS_ACTUALLY '=' TBOOL ';'",
"general_reject_hold_time : TREJECT_HOLD_TIME '=' timespec ';'",
"general_tkline_expire_notices : TKLINE_EXPIRE_NOTICES '=' TBOOL ';'",
"general_kill_chase_time_limit : KILL_CHASE_TIME_LIMIT '=' NUMBER ';'",
"general_hide_spoof_ips : HIDE_SPOOF_IPS '=' TBOOL ';'",
"general_ignore_bogus_ts : IGNORE_BOGUS_TS '=' TBOOL ';'",
"general_disable_remote_commands : DISABLE_REMOTE_COMMANDS '=' TBOOL ';'",
"general_failed_oper_notice : FAILED_OPER_NOTICE '=' TBOOL ';'",
"general_anti_nick_flood : ANTI_NICK_FLOOD '=' TBOOL ';'",
"general_max_nick_time : MAX_NICK_TIME '=' timespec ';'",
"general_max_nick_changes : MAX_NICK_CHANGES '=' NUMBER ';'",
"general_max_accept : MAX_ACCEPT '=' NUMBER ';'",
"general_anti_spam_exit_message_time : ANTI_SPAM_EXIT_MESSAGE_TIME '=' timespec ';'",
"general_ts_warn_delta : TS_WARN_DELTA '=' timespec ';'",
"general_ts_max_delta : TS_MAX_DELTA '=' timespec ';'",
"general_havent_read_conf : HAVENT_READ_CONF '=' NUMBER ';'",
"general_kline_with_reason : KLINE_WITH_REASON '=' TBOOL ';'",
"general_kline_reason : KLINE_REASON '=' QSTRING ';'",
"general_invisible_on_connect : INVISIBLE_ON_CONNECT '=' TBOOL ';'",
"general_mode_z : MODE_Z '=' TBOOL ';'",
"general_warn_no_nline : WARN_NO_NLINE '=' TBOOL ';'",
"general_stats_e_disabled : STATS_E_DISABLED '=' TBOOL ';'",
"general_stats_o_oper_only : STATS_O_OPER_ONLY '=' TBOOL ';'",
"general_stats_P_oper_only : STATS_P_OPER_ONLY '=' TBOOL ';'",
"general_stats_k_oper_only : STATS_K_OPER_ONLY '=' TBOOL ';'",
"general_stats_k_oper_only : STATS_K_OPER_ONLY '=' TMASKED ';'",
"general_stats_i_oper_only : STATS_I_OPER_ONLY '=' TBOOL ';'",
"general_stats_i_oper_only : STATS_I_OPER_ONLY '=' TMASKED ';'",
"general_pace_wait : PACE_WAIT '=' timespec ';'",
"general_caller_id_wait : CALLER_ID_WAIT '=' timespec ';'",
"general_opers_bypass_callerid : OPERS_BYPASS_CALLERID '=' TBOOL ';'",
"general_pace_wait_simple : PACE_WAIT_SIMPLE '=' timespec ';'",
"general_short_motd : SHORT_MOTD '=' TBOOL ';'",
"general_no_oper_flood : NO_OPER_FLOOD '=' TBOOL ';'",
"general_true_no_oper_flood : TRUE_NO_OPER_FLOOD '=' TBOOL ';'",
"general_oper_pass_resv : OPER_PASS_RESV '=' TBOOL ';'",
"general_message_locale : MESSAGE_LOCALE '=' QSTRING ';'",
"general_idletime : IDLETIME '=' timespec ';'",
"general_dots_in_ident : DOTS_IN_IDENT '=' NUMBER ';'",
"general_max_targets : MAX_TARGETS '=' NUMBER ';'",
"general_servlink_path : SERVLINK_PATH '=' QSTRING ';'",
"general_default_cipher_preference : DEFAULT_CIPHER_PREFERENCE '=' QSTRING ';'",
"general_compression_level : COMPRESSION_LEVEL '=' NUMBER ';'",
"general_use_egd : USE_EGD '=' TBOOL ';'",
"general_egdpool_path : EGDPOOL_PATH '=' QSTRING ';'",
"general_ping_cookie : PING_COOKIE '=' TBOOL ';'",
"general_disable_auth : DISABLE_AUTH '=' TBOOL ';'",
"general_throttle_time : THROTTLE_TIME '=' timespec ';'",
"$$29 :",
"general_oper_umodes : OPER_UMODES $$29 '=' umode_oitems ';'",
"umode_oitems : umode_oitems ',' umode_oitem",
"umode_oitems : umode_oitem",
"umode_oitem : T_BOTS",
"umode_oitem : T_CCONN",
"umode_oitem : T_CCONN_FULL",
"umode_oitem : T_DEAF",
"umode_oitem : T_DEBUG",
"umode_oitem : T_FULL",
"umode_oitem : T_SKILL",
"umode_oitem : T_NCHANGE",
"umode_oitem : T_REJ",
"umode_oitem : T_UNAUTH",
"umode_oitem : T_SPY",
"umode_oitem : T_EXTERNAL",
"umode_oitem : T_OPERWALL",
"umode_oitem : T_SERVNOTICE",
"umode_oitem : T_INVISIBLE",
"umode_oitem : T_WALLOP",
"umode_oitem : T_SOFTCALLERID",
"umode_oitem : T_CALLERID",
"umode_oitem : T_LOCOPS",
"$$30 :",
"general_oper_only_umodes : OPER_ONLY_UMODES $$30 '=' umode_items ';'",
"umode_items : umode_items ',' umode_item",
"umode_items : umode_item",
"umode_item : T_BOTS",
"umode_item : T_CCONN",
"umode_item : T_CCONN_FULL",
"umode_item : T_DEAF",
"umode_item : T_DEBUG",
"umode_item : T_FULL",
"umode_item : T_SKILL",
"umode_item : T_NCHANGE",
"umode_item : T_REJ",
"umode_item : T_UNAUTH",
"umode_item : T_SPY",
"umode_item : T_EXTERNAL",
"umode_item : T_OPERWALL",
"umode_item : T_SERVNOTICE",
"umode_item : T_INVISIBLE",
"umode_item : T_WALLOP",
"umode_item : T_SOFTCALLERID",
"umode_item : T_CALLERID",
"umode_item : T_LOCOPS",
"umode_item : T_SNOOP",
"general_min_nonwildcard : MIN_NONWILDCARD '=' NUMBER ';'",
"general_min_nonwildcard_simple : MIN_NONWILDCARD_SIMPLE '=' NUMBER ';'",
"general_default_floodcount : DEFAULT_FLOODCOUNT '=' NUMBER ';'",
"general_client_flood : T_CLIENT_FLOOD '=' sizespec ';'",
"general_dot_in_ip6_addr : DOT_IN_IP6_ADDR '=' TBOOL ';'",
"$$31 :",
"gline_entry : GLINES $$31 '{' gline_items '}' ';'",
"gline_items : gline_items gline_item",
"gline_items : gline_item",
"gline_item : gline_enable",
"gline_item : gline_duration",
"gline_item : gline_logging",
"gline_item : gline_user",
"gline_item : gline_server",
"gline_item : gline_action",
"gline_item : error",
"gline_enable : ENABLE '=' TBOOL ';'",
"gline_duration : DURATION '=' timespec ';'",
"$$32 :",
"gline_logging : LOGGING $$32 '=' gline_logging_types ';'",
"gline_logging_types : gline_logging_types ',' gline_logging_type_item",
"gline_logging_types : gline_logging_type_item",
"gline_logging_type_item : T_REJECT",
"gline_logging_type_item : T_BLOCK",
"gline_user : USER '=' QSTRING ';'",
"gline_server : NAME '=' QSTRING ';'",
"$$33 :",
"gline_action : ACTION $$33 '=' gdeny_types ';'",
"gdeny_types : gdeny_types ',' gdeny_type_item",
"gdeny_types : gdeny_type_item",
"gdeny_type_item : T_REJECT",
"gdeny_type_item : T_BLOCK",
"channel_entry : CHANNEL '{' channel_items '}' ';'",
"channel_items : channel_items channel_item",
"channel_items : channel_item",
"channel_item : channel_disable_local_channels",
"channel_item : channel_use_except",
"channel_item : channel_use_invex",
"channel_item : channel_use_knock",
"channel_item : channel_max_bans",
"channel_item : channel_knock_delay",
"channel_item : channel_knock_delay_channel",
"channel_item : channel_max_chans_per_user",
"channel_item : channel_quiet_on_ban",
"channel_item : channel_default_split_user_count",
"channel_item : channel_default_split_server_count",
"channel_item : channel_no_create_on_split",
"channel_item : channel_restrict_channels",
"channel_item : channel_no_join_on_split",
"channel_item : channel_burst_topicwho",
"channel_item : channel_jflood_count",
"channel_item : channel_jflood_time",
"channel_item : channel_disable_fake_channels",
"channel_item : error",
"channel_disable_fake_channels : DISABLE_FAKE_CHANNELS '=' TBOOL ';'",
"channel_restrict_channels : RESTRICT_CHANNELS '=' TBOOL ';'",
"channel_disable_local_channels : DISABLE_LOCAL_CHANNELS '=' TBOOL ';'",
"channel_use_except : USE_EXCEPT '=' TBOOL ';'",
"channel_use_invex : USE_INVEX '=' TBOOL ';'",
"channel_use_knock : USE_KNOCK '=' TBOOL ';'",
"channel_knock_delay : KNOCK_DELAY '=' timespec ';'",
"channel_knock_delay_channel : KNOCK_DELAY_CHANNEL '=' timespec ';'",
"channel_max_chans_per_user : MAX_CHANS_PER_USER '=' NUMBER ';'",
"channel_quiet_on_ban : QUIET_ON_BAN '=' TBOOL ';'",
"channel_max_bans : MAX_BANS '=' NUMBER ';'",
"channel_default_split_user_count : DEFAULT_SPLIT_USER_COUNT '=' NUMBER ';'",
"channel_default_split_server_count : DEFAULT_SPLIT_SERVER_COUNT '=' NUMBER ';'",
"channel_no_create_on_split : NO_CREATE_ON_SPLIT '=' TBOOL ';'",
"channel_no_join_on_split : NO_JOIN_ON_SPLIT '=' TBOOL ';'",
"channel_burst_topicwho : BURST_TOPICWHO '=' TBOOL ';'",
"channel_jflood_count : JOIN_FLOOD_COUNT '=' NUMBER ';'",
"channel_jflood_time : JOIN_FLOOD_TIME '=' timespec ';'",
"serverhide_entry : SERVERHIDE '{' serverhide_items '}' ';'",
"serverhide_items : serverhide_items serverhide_item",
"serverhide_items : serverhide_item",
"serverhide_item : serverhide_flatten_links",
"serverhide_item : serverhide_hide_servers",
"serverhide_item : serverhide_links_delay",
"serverhide_item : serverhide_disable_hidden",
"serverhide_item : serverhide_hidden",
"serverhide_item : serverhide_hidden_name",
"serverhide_item : serverhide_hide_server_ips",
"serverhide_item : error",
"serverhide_flatten_links : FLATTEN_LINKS '=' TBOOL ';'",
"serverhide_hide_servers : HIDE_SERVERS '=' TBOOL ';'",
"serverhide_hidden_name : HIDDEN_NAME '=' QSTRING ';'",
"serverhide_links_delay : LINKS_DELAY '=' timespec ';'",
"serverhide_hidden : HIDDEN '=' TBOOL ';'",
"serverhide_disable_hidden : DISABLE_HIDDEN '=' TBOOL ';'",
"serverhide_hide_server_ips : HIDE_SERVER_IPS '=' TBOOL ';'",
};
#endif
#if YYDEBUG
#include <stdio.h>
#endif
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH 10000
#endif
#endif
#define YYINITSTACKSIZE 200
int yydebug;
int yynerrs;
int yyerrflag;
int yychar;
short *yyssp;
YYSTYPE *yyvsp;
YYSTYPE yyval;
YYSTYPE yylval;
short *yyss;
short *yysslim;
YYSTYPE *yyvs;
int yystacksize;
/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack()
{
    int newsize, i;
    short *newss;
    YYSTYPE *newvs;

    if ((newsize = yystacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return -1;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;
    i = yyssp - yyss;
    newss = yyss ? (short *)realloc(yyss, newsize * sizeof *newss) :
      (short *)malloc(newsize * sizeof *newss);
    if (newss == NULL)
        return -1;
    yyss = newss;
    yyssp = newss + i;
    newvs = yyvs ? (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs) :
      (YYSTYPE *)malloc(newsize * sizeof *newvs);
    if (newvs == NULL)
        return -1;
    yyvs = newvs;
    yyvsp = newvs + i;
    yystacksize = newsize;
    yysslim = yyss + newsize - 1;
    return 0;
}

#define YYABORT goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR goto yyerrlab

#ifndef YYPARSE_PARAM
#if defined(__cplusplus) || __STDC__
#define YYPARSE_PARAM_ARG void
#define YYPARSE_PARAM_DECL
#else	/* ! ANSI-C/C++ */
#define YYPARSE_PARAM_ARG
#define YYPARSE_PARAM_DECL
#endif	/* ANSI-C/C++ */
#else	/* YYPARSE_PARAM */
#ifndef YYPARSE_PARAM_TYPE
#define YYPARSE_PARAM_TYPE void *
#endif
#if defined(__cplusplus) || __STDC__
#define YYPARSE_PARAM_ARG YYPARSE_PARAM_TYPE YYPARSE_PARAM
#define YYPARSE_PARAM_DECL
#else	/* ! ANSI-C/C++ */
#define YYPARSE_PARAM_ARG YYPARSE_PARAM
#define YYPARSE_PARAM_DECL YYPARSE_PARAM_TYPE YYPARSE_PARAM;
#endif	/* ANSI-C/C++ */
#endif	/* ! YYPARSE_PARAM */

int
yyparse (YYPARSE_PARAM_ARG)
    YYPARSE_PARAM_DECL
{
    int yym, yyn, yystate;
#if YYDEBUG
    const char *yys;

    if ((yys = getenv("YYDEBUG")))
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif

    yynerrs = 0;
    yyerrflag = 0;
    yychar = (-1);

    if (yyss == NULL && yygrowstack()) goto yyoverflow;
    yyssp = yyss;
    yyvsp = yyvs;
    *yyssp = yystate = 0;

yyloop:
    if ((yyn = yydefred[yystate])) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yyssp >= yysslim && yygrowstack())
        {
            goto yyoverflow;
        }
        *++yyssp = yystate = yytable[yyn];
        *++yyvsp = yylval;
        yychar = (-1);
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;
#if defined(lint) || defined(__GNUC__)
    goto yynewerror;
#endif
yynewerror:
    yyerror("syntax error");
#if defined(lint) || defined(__GNUC__)
    goto yyerrlab;
#endif
yyerrlab:
    ++yynerrs;
yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yyssp]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yyssp, yytable[yyn]);
#endif
                if (yyssp >= yysslim && yygrowstack())
                {
                    goto yyoverflow;
                }
                *++yyssp = yystate = yytable[yyn];
                *++yyvsp = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yyssp);
#endif
                if (yyssp <= yyss) goto yyabort;
                --yyssp;
                --yyvsp;
            }
        }
    }
    else
    {
        if (yychar == 0) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = (-1);
        goto yyloop;
    }
yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    if (yym)
        yyval = yyvsp[1-yym];
    else
        memset(&yyval, 0, sizeof yyval);
    switch (yyn)
    {
case 26:
#line 432 "ircd_parser.y"
{ yyval.number = 0; }
break;
case 28:
#line 434 "ircd_parser.y"
{
			yyval.number = yyvsp[-1].number + yyvsp[0].number;
		}
break;
case 29:
#line 438 "ircd_parser.y"
{
			yyval.number = yyvsp[-2].number + yyvsp[0].number;
		}
break;
case 30:
#line 442 "ircd_parser.y"
{
			yyval.number = yyvsp[-2].number * 60 + yyvsp[0].number;
		}
break;
case 31:
#line 446 "ircd_parser.y"
{
			yyval.number = yyvsp[-2].number * 60 * 60 + yyvsp[0].number;
		}
break;
case 32:
#line 450 "ircd_parser.y"
{
			yyval.number = yyvsp[-2].number * 60 * 60 * 24 + yyvsp[0].number;
		}
break;
case 33:
#line 454 "ircd_parser.y"
{
			yyval.number = yyvsp[-2].number * 60 * 60 * 24 * 7 + yyvsp[0].number;
		}
break;
case 34:
#line 459 "ircd_parser.y"
{ yyval.number = 0; }
break;
case 36:
#line 460 "ircd_parser.y"
{ yyval.number = yyvsp[-1].number + yyvsp[0].number; }
break;
case 37:
#line 461 "ircd_parser.y"
{ yyval.number = yyvsp[-2].number + yyvsp[0].number; }
break;
case 38:
#line 462 "ircd_parser.y"
{ yyval.number = yyvsp[-2].number * 1024 + yyvsp[0].number; }
break;
case 39:
#line 463 "ircd_parser.y"
{ yyval.number = yyvsp[-2].number * 1024 * 1024 + yyvsp[0].number; }
break;
case 46:
#line 477 "ircd_parser.y"
{
#ifndef STATIC_MODULES /* NOOP in the static case */
  if (ypass == 2)
  {
    char *m_bn;

    m_bn = basename(yylval.string);

    /* I suppose we should just ignore it if it is already loaded(since
     * otherwise we would flood the opers on rehash) -A1kmm.
     */
    add_conf_module(yylval.string);
  }
#endif
}
break;
case 47:
#line 494 "ircd_parser.y"
{
#ifndef STATIC_MODULES
  if (ypass == 2)
    mod_add_path(yylval.string);
#endif
}
break;
case 65:
#line 519 "ircd_parser.y"
{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2 && ServerInfo.ctx) 
  {
    if (!ServerInfo.rsa_private_key_file)
    {
      yyerror("No rsa_private_key_file specified, SSL disabled");
      break;
    }

    if (SSL_CTX_use_certificate_file(ServerInfo.ctx,
      yylval.string, SSL_FILETYPE_PEM) <= 0)
    {
      yyerror(ERR_lib_error_string(ERR_get_error()));
      break;
    }

    if (SSL_CTX_use_PrivateKey_file(ServerInfo.ctx,
      ServerInfo.rsa_private_key_file, SSL_FILETYPE_PEM) <= 0)
    {
      yyerror(ERR_lib_error_string(ERR_get_error()));
      break;
    }

    if (!SSL_CTX_check_private_key(ServerInfo.ctx))
    {
      yyerror("RSA private key does not match the SSL certificate public key!");
      break;
    }
  }
#endif
}
break;
case 66:
#line 553 "ircd_parser.y"
{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 1)
  {
    BIO *file;

    if (ServerInfo.rsa_private_key)
    {
      RSA_free(ServerInfo.rsa_private_key);
      ServerInfo.rsa_private_key = NULL;
    }

    if (ServerInfo.rsa_private_key_file)
    {
      MyFree(ServerInfo.rsa_private_key_file);
      ServerInfo.rsa_private_key_file = NULL;
    }

    DupString(ServerInfo.rsa_private_key_file, yylval.string);

    if ((file = BIO_new_file(yylval.string, "r")) == NULL)
    {
      yyerror("File open failed, ignoring");
      break;
    }

    ServerInfo.rsa_private_key = (RSA *)PEM_read_bio_RSAPrivateKey(file, NULL,
      0, NULL);

    BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);

    if (ServerInfo.rsa_private_key == NULL)
    {
      yyerror("Couldn't extract key, ignoring");
      break;
    }

    if (!RSA_check_key(ServerInfo.rsa_private_key))
    {
      RSA_free(ServerInfo.rsa_private_key);
      ServerInfo.rsa_private_key = NULL;

      yyerror("Invalid key, ignoring");
      break;
    }

    /* require 2048 bit (256 byte) key */
    if (RSA_size(ServerInfo.rsa_private_key) != 256)
    {
      RSA_free(ServerInfo.rsa_private_key);
      ServerInfo.rsa_private_key = NULL;

      yyerror("Not a 2048 bit key, ignoring");
    }
  }
#endif
}
break;
case 67:
#line 613 "ircd_parser.y"
{
  /* this isn't rehashable */
  if (ypass == 2)
  {
    if (ServerInfo.name == NULL)
    {
      /* the ircd will exit() in main() if we dont set one */
      if (strlen(yylval.string) <= HOSTLEN)
        DupString(ServerInfo.name, yylval.string);
    }
  }
}
break;
case 68:
#line 627 "ircd_parser.y"
{
  /* this isn't rehashable */
  if (ypass == 2 && !ServerInfo.sid)
  {
    if (valid_sid(yylval.string))
      DupString(ServerInfo.sid, yylval.string);
    else
    {
      ilog(L_ERROR, "Ignoring config file entry SID -- invalid SID. Aborting.");
      exit(0);
    }
  }
}
break;
case 69:
#line 642 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(ServerInfo.description);
    DupString(ServerInfo.description,yylval.string);
  }
}
break;
case 70:
#line 651 "ircd_parser.y"
{
  if (ypass == 2)
  {
    char *p;

    if ((p = strchr(yylval.string, ' ')) != NULL)
      p = '\0';

    MyFree(ServerInfo.network_name);
    DupString(ServerInfo.network_name, yylval.string);
  }
}
break;
case 71:
#line 665 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(ServerInfo.network_desc);
    DupString(ServerInfo.network_desc, yylval.string);
  }
}
break;
case 72:
#line 674 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(ServerInfo.services_name);
    DupString(ServerInfo.services_name, yylval.string);
  }
}
break;
case 73:
#line 683 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(ServerInfo.help_channel);
    DupString(ServerInfo.help_channel, yylval.string);
  }
}
break;
case 74:
#line 692 "ircd_parser.y"
{
  if (ypass == 2 && *yylval.string != '*')
  {
    struct addrinfo hints, *res;

    memset(&hints, 0, sizeof(hints));

    hints.ai_family   = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;

    if (irc_getaddrinfo(yylval.string, NULL, &hints, &res))
      ilog(L_ERROR, "Invalid netmask for server vhost(%s)", yylval.string);
    else
    {
      assert(res != NULL);

      memcpy(&ServerInfo.ip, res->ai_addr, res->ai_addrlen);
      ServerInfo.ip.ss.ss_family = res->ai_family;
      ServerInfo.ip.ss_len = res->ai_addrlen;
      irc_freeaddrinfo(res);

      ServerInfo.specific_ipv4_vhost = 1;
    }
  }
}
break;
case 75:
#line 720 "ircd_parser.y"
{
#ifdef IPV6
  if (ypass == 2 && *yylval.string != '*')
  {
    struct addrinfo hints, *res;

    memset(&hints, 0, sizeof(hints));

    hints.ai_family   = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;

    if (irc_getaddrinfo(yylval.string, NULL, &hints, &res))
      ilog(L_ERROR, "Invalid netmask for server vhost6(%s)", yylval.string);
    else
    {
      assert(res != NULL);

      memcpy(&ServerInfo.ip6, res->ai_addr, res->ai_addrlen);
      ServerInfo.ip6.ss.ss_family = res->ai_family;
      ServerInfo.ip6.ss_len = res->ai_addrlen;
      irc_freeaddrinfo(res);

      ServerInfo.specific_ipv6_vhost = 1;
    }
  }
#endif
}
break;
case 76:
#line 750 "ircd_parser.y"
{
  if (ypass == 2)
  {
    recalc_fdlimit(NULL);

    if (yyvsp[-1].number < MAXCLIENTS_MIN)
    {
      char buf[IRCD_BUFSIZE];
      ircsprintf(buf, "MAXCLIENTS too low, setting to %d", MAXCLIENTS_MIN);
      yyerror(buf);
    }
    else if (yyvsp[-1].number > MAXCLIENTS_MAX)
    {
      char buf[IRCD_BUFSIZE];
      ircsprintf(buf, "MAXCLIENTS too high, setting to %d", MAXCLIENTS_MAX);
      yyerror(buf);
    }
    else
      ServerInfo.max_clients = yyvsp[-1].number;
  }
}
break;
case 77:
#line 773 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
    {
      /* Don't become a hub if we have a lazylink active. */
      if (!ServerInfo.hub && uplink && IsCapable(uplink, CAP_LL))
      {
        sendto_realops_flags(UMODE_ALL, L_ALL,
                             "Ignoring config file line hub=yes; "
                             "due to active LazyLink (%s)", uplink->name);
      }
      else
      {
        ServerInfo.hub = 1;
        uplink = NULL;
        delete_capability("HUB");
        add_capability("HUB", CAP_HUB, 1);
      }
    }
    else if (ServerInfo.hub)
    {
      dlink_node *ptr = NULL;

      ServerInfo.hub = 0;
      delete_capability("HUB");

      /* Don't become a leaf if we have a lazylink active. */
      DLINK_FOREACH(ptr, serv_list.head)
      {
        const struct Client *acptr = ptr->data;
        if (MyConnect(acptr) && IsCapable(acptr, CAP_LL))
        {
          sendto_realops_flags(UMODE_ALL, L_ALL,
                               "Ignoring config file line hub=no; "
                               "due to active LazyLink (%s)",
                               acptr->name);
          add_capability("HUB", CAP_HUB, 1);
          ServerInfo.hub = 1;
          break;
        }
      }
    }
  }
}
break;
case 85:
#line 829 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(AdminInfo.name);
    DupString(AdminInfo.name, yylval.string);
  }
}
break;
case 86:
#line 838 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(AdminInfo.email);
    DupString(AdminInfo.email, yylval.string);
  }
}
break;
case 87:
#line 847 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(AdminInfo.description);
    DupString(AdminInfo.description, yylval.string);
  }
}
break;
case 104:
#line 874 "ircd_parser.y"
{
                        }
break;
case 105:
#line 878 "ircd_parser.y"
{
                        }
break;
case 106:
#line 882 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.userlog, yylval.string,
            sizeof(ConfigLoggingEntry.userlog));
}
break;
case 107:
#line 889 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.failed_operlog, yylval.string,
            sizeof(ConfigLoggingEntry.failed_operlog));
}
break;
case 108:
#line 896 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.operlog, yylval.string,
            sizeof(ConfigLoggingEntry.operlog));
}
break;
case 109:
#line 903 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.operspylog, yylval.string,
            sizeof(ConfigLoggingEntry.operspylog));
}
break;
case 110:
#line 910 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.glinelog, yylval.string,
            sizeof(ConfigLoggingEntry.glinelog));
}
break;
case 111:
#line 917 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.klinelog, yylval.string,
            sizeof(ConfigLoggingEntry.klinelog));
}
break;
case 112:
#line 924 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.ioerrlog, yylval.string,
            sizeof(ConfigLoggingEntry.ioerrlog));
}
break;
case 113:
#line 931 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.killlog, yylval.string,
            sizeof(ConfigLoggingEntry.killlog));
}
break;
case 114:
#line 938 "ircd_parser.y"
{ 
  if (ypass == 2)
    set_log_level(L_CRIT);
}
break;
case 115:
#line 942 "ircd_parser.y"
{
  if (ypass == 2)
    set_log_level(L_ERROR);
}
break;
case 116:
#line 946 "ircd_parser.y"
{
  if (ypass == 2)
    set_log_level(L_WARN);
}
break;
case 117:
#line 950 "ircd_parser.y"
{
  if (ypass == 2)
    set_log_level(L_NOTICE);
}
break;
case 118:
#line 954 "ircd_parser.y"
{
  if (ypass == 2)
    set_log_level(L_TRACE);
}
break;
case 119:
#line 958 "ircd_parser.y"
{
  if (ypass == 2)
    set_log_level(L_INFO);
}
break;
case 120:
#line 962 "ircd_parser.y"
{
  if (ypass == 2)
    set_log_level(L_DEBUG);
}
break;
case 121:
#line 968 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigLoggingEntry.use_logging = yylval.number;
}
break;
case 122:
#line 977 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(OPER_TYPE);
    yy_aconf = map_to_conf(yy_conf);
    SetConfEncrypted(yy_aconf); /* Yes, the default is encrypted */
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 123:
#line 990 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp;
    dlink_node *ptr;
    dlink_node *next_ptr;

    conf_add_class_to_conf(yy_conf, class_name);

    /* Now, make sure there is a copy of the "base" given oper
     * block in each of the collected copies
     */

    DLINK_FOREACH_SAFE(ptr, next_ptr, col_conf_list.head)
    {
      struct AccessItem *new_aconf;
      struct ConfItem *new_conf;
      yy_tmp = ptr->data;

      new_conf = make_conf_item(OPER_TYPE);
      new_aconf = (struct AccessItem *)map_to_conf(new_conf);

      new_aconf->flags = yy_aconf->flags;

      if (yy_conf->name != NULL)
        DupString(new_conf->name, yy_conf->name);
      if (yy_tmp->user != NULL)
	DupString(new_aconf->user, yy_tmp->user);
      else
	DupString(new_aconf->user, "*");
      if (yy_tmp->host != NULL)
	DupString(new_aconf->host, yy_tmp->host);
      else
	DupString(new_aconf->host, "*");
      conf_add_class_to_conf(new_conf, class_name);
      if (yy_aconf->passwd != NULL)
        DupString(new_aconf->passwd, yy_aconf->passwd);

      new_aconf->port = yy_aconf->port;
#ifdef HAVE_LIBCRYPTO
      if (yy_aconf->rsa_public_key_file != NULL)
      {
        BIO *file;

        DupString(new_aconf->rsa_public_key_file,
		  yy_aconf->rsa_public_key_file);

        file = BIO_new_file(yy_aconf->rsa_public_key_file, "r");
        new_aconf->rsa_public_key = (RSA *)PEM_read_bio_RSA_PUBKEY(file, 
							   NULL, 0, NULL);
        BIO_set_close(file, BIO_CLOSE);
        BIO_free(file);
      }
#endif

#ifdef HAVE_LIBCRYPTO
      if (yy_tmp->name && (yy_tmp->passwd || yy_aconf->rsa_public_key)
	  && yy_tmp->host)
#else
      if (yy_tmp->name && yy_tmp->passwd && yy_tmp->host)
#endif
      {
        conf_add_class_to_conf(new_conf, class_name);
	if (yy_tmp->name != NULL)
	  DupString(new_conf->name, yy_tmp->name);
      }

      dlinkDelete(&yy_tmp->node, &col_conf_list);
      free_collect_item(yy_tmp);
    }

    yy_conf = NULL;
    yy_aconf = NULL;


    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 152:
#line 1082 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (strlen(yylval.string) > OPERNICKLEN)
      yylval.string[OPERNICKLEN] = '\0';

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 153:
#line 1094 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (strlen(yylval.string) > OPERNICKLEN)
      yylval.string[OPERNICKLEN] = '\0';

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 154:
#line 1106 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    if (yy_aconf->user == NULL)
    {
      DupString(yy_aconf->user, userbuf);
      DupString(yy_aconf->host, hostbuf);
    }
    else
    {
      struct CollectItem *yy_tmp = MyMalloc(sizeof(struct CollectItem));

      DupString(yy_tmp->user, userbuf);
      DupString(yy_tmp->host, hostbuf);

      dlinkAdd(yy_tmp, &yy_tmp->node, &col_conf_list);
    }
  }
}
break;
case 155:
#line 1140 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yy_aconf->passwd != NULL)
      memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

    MyFree(yy_aconf->passwd);
    DupString(yy_aconf->passwd, yylval.string);
  }
}
break;
case 156:
#line 1152 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      SetConfEncrypted(yy_aconf);
    else
      ClearConfEncrypted(yy_aconf);
  }
}
break;
case 157:
#line 1163 "ircd_parser.y"
{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    BIO *file;

    if (yy_aconf->rsa_public_key != NULL)
    {
      RSA_free(yy_aconf->rsa_public_key);
      yy_aconf->rsa_public_key = NULL;
    }

    if (yy_aconf->rsa_public_key_file != NULL)
    {
      MyFree(yy_aconf->rsa_public_key_file);
      yy_aconf->rsa_public_key_file = NULL;
    }

    DupString(yy_aconf->rsa_public_key_file, yylval.string);
    file = BIO_new_file(yylval.string, "r");

    if (file == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- file doesn't exist");
      break;
    }

    yy_aconf->rsa_public_key = (RSA *)PEM_read_bio_RSA_PUBKEY(file, NULL, 0, NULL);

    if (yy_aconf->rsa_public_key == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- Key invalid; check key syntax.");
      break;
    }

    BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);
  }
#endif /* HAVE_LIBCRYPTO */
}
break;
case 158:
#line 1205 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(class_name);
    DupString(class_name, yylval.string);
  }
}
break;
case 159:
#line 1214 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes = 0;
}
break;
case 163:
#line 1221 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_BOTS;
}
break;
case 164:
#line 1225 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_CCONN;
}
break;
case 165:
#line 1229 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_CCONN_FULL;
}
break;
case 166:
#line 1233 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_DEAF;
}
break;
case 167:
#line 1237 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_DEBUG;
}
break;
case 168:
#line 1241 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_FULL;
}
break;
case 169:
#line 1245 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SKILL;
}
break;
case 170:
#line 1249 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_NCHANGE;
}
break;
case 171:
#line 1253 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_REJ;
}
break;
case 172:
#line 1257 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_UNAUTH;
}
break;
case 173:
#line 1261 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SPY;
}
break;
case 174:
#line 1265 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_EXTERNAL;
}
break;
case 175:
#line 1269 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_OPERWALL;
}
break;
case 176:
#line 1273 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SERVNOTICE;
}
break;
case 177:
#line 1277 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_INVISIBLE;
}
break;
case 178:
#line 1281 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_WALLOP;
}
break;
case 179:
#line 1285 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SOFTCALLERID;
}
break;
case 180:
#line 1289 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_CALLERID;
}
break;
case 181:
#line 1293 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_LOCOPS;
}
break;
case 182:
#line 1297 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SNOOP;
}
break;
case 183:
#line 1303 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_GLOBAL_KILL;
    else
      yy_aconf->port &= ~OPER_FLAG_GLOBAL_KILL;
  }
}
break;
case 184:
#line 1314 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_REMOTE;
    else
      yy_aconf->port &= ~OPER_FLAG_REMOTE; 
  }
}
break;
case 185:
#line 1325 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_REMOTEBAN;
    else
      yy_aconf->port &= ~OPER_FLAG_REMOTEBAN;
  }
}
break;
case 186:
#line 1336 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_K;
    else
      yy_aconf->port &= ~OPER_FLAG_K;
  }
}
break;
case 187:
#line 1347 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_X;
    else
      yy_aconf->port &= ~OPER_FLAG_X;
  }
}
break;
case 188:
#line 1358 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_UNKLINE;
    else
      yy_aconf->port &= ~OPER_FLAG_UNKLINE; 
  }
}
break;
case 189:
#line 1369 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_GLINE;
    else
      yy_aconf->port &= ~OPER_FLAG_GLINE;
  }
}
break;
case 190:
#line 1380 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_N;
    else
      yy_aconf->port &= ~OPER_FLAG_N;
  }
}
break;
case 191:
#line 1391 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_DIE;
    else
      yy_aconf->port &= ~OPER_FLAG_DIE;
  }
}
break;
case 192:
#line 1402 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_REHASH;
    else
      yy_aconf->port &= ~OPER_FLAG_REHASH;
  }
}
break;
case 193:
#line 1413 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_ADMIN;
    else
      yy_aconf->port &= ~OPER_FLAG_ADMIN;
  }
}
break;
case 194:
#line 1424 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_HIDDEN_ADMIN;
    else
      yy_aconf->port &= ~OPER_FLAG_HIDDEN_ADMIN;
  }
}
break;
case 195:
#line 1435 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_HIDDEN_OPER;
    else
      yy_aconf->port &= ~OPER_FLAG_HIDDEN_OPER;
  }
}
break;
case 196:
#line 1446 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_OPERWALL;
    else
      yy_aconf->port &= ~OPER_FLAG_OPERWALL;
  }
}
break;
case 197:
#line 1457 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_SNOOP;
    else
      yy_aconf->port &= ~OPER_FLAG_SNOOP;
  }
}
break;
case 198:
#line 1468 "ircd_parser.y"
{
}
break;
case 202:
#line 1472 "ircd_parser.y"
{ not_atom = 1; }
break;
case 204:
#line 1473 "ircd_parser.y"
{ not_atom = 0; }
break;
case 206:
#line 1476 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom)yy_aconf->port &= ~OPER_FLAG_GLOBAL_KILL;
    else yy_aconf->port |= OPER_FLAG_GLOBAL_KILL;
  }
}
break;
case 207:
#line 1483 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_REMOTE;
    else yy_aconf->port |= OPER_FLAG_REMOTE;
  }
}
break;
case 208:
#line 1490 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_K;
    else yy_aconf->port |= OPER_FLAG_K;
  }
}
break;
case 209:
#line 1497 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_UNKLINE;
    else yy_aconf->port |= OPER_FLAG_UNKLINE;
  } 
}
break;
case 210:
#line 1504 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_X;
    else yy_aconf->port |= OPER_FLAG_X;
  }
}
break;
case 211:
#line 1511 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_GLINE;
    else yy_aconf->port |= OPER_FLAG_GLINE;
  }
}
break;
case 212:
#line 1518 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_DIE;
    else yy_aconf->port |= OPER_FLAG_DIE;
  }
}
break;
case 213:
#line 1525 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_REHASH;
    else yy_aconf->port |= OPER_FLAG_REHASH;
  }
}
break;
case 214:
#line 1532 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_ADMIN;
    else yy_aconf->port |= OPER_FLAG_ADMIN;
  }
}
break;
case 215:
#line 1539 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_HIDDEN_ADMIN;
    else yy_aconf->port |= OPER_FLAG_HIDDEN_ADMIN;
  }
}
break;
case 216:
#line 1546 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_N;
    else yy_aconf->port |= OPER_FLAG_N;
  }
}
break;
case 217:
#line 1553 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_OPERWALL;
    else yy_aconf->port |= OPER_FLAG_OPERWALL;
  }
}
break;
case 218:
#line 1560 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_OPER_SPY;
    else yy_aconf->port |= OPER_FLAG_OPER_SPY;
  }
}
break;
case 219:
#line 1567 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_HIDDEN_OPER;
    else yy_aconf->port |= OPER_FLAG_HIDDEN_OPER;
  }
}
break;
case 220:
#line 1574 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_REMOTEBAN;
    else yy_aconf->port |= OPER_FLAG_REMOTEBAN;
  }
}
break;
case 221:
#line 1581 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) ClearConfEncrypted(yy_aconf);
    else SetConfEncrypted(yy_aconf);
  }
}
break;
case 222:
#line 1588 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_SNOOP;
    else yy_aconf->port |= OPER_FLAG_SNOOP;
  }
}
break;
case 223:
#line 1600 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(WEBIRC_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
}
break;
case 224:
#line 1607 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 230:
#line 1619 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(yy_aconf->host);
    DupString(yy_aconf->host, yylval.string);
  }
}
break;
case 231:
#line 1628 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yy_aconf->passwd != NULL)
      memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

    MyFree(yy_aconf->passwd);
    DupString(yy_aconf->passwd, yylval.string);
  }
}
break;
case 232:
#line 1643 "ircd_parser.y"
{
  if (ypass == 1)
  {
    yy_conf = make_conf_item(CLASS_TYPE);
    yy_class = map_to_conf(yy_conf);
  }
}
break;
case 233:
#line 1650 "ircd_parser.y"
{
  if (ypass == 1)
  {
    struct ConfItem *cconf = NULL;
    struct ClassItem *class = NULL;

    if (yy_class_name == NULL)
      delete_conf_item(yy_conf);
    else
    {
      cconf = find_exact_name_conf(CLASS_TYPE, yy_class_name, NULL, NULL);

      if (cconf != NULL)		/* The class existed already */
      {
        int user_count = 0;

        rebuild_cidr_class(cconf, yy_class);

        class = map_to_conf(cconf);

        user_count = class->curr_user_count;
        memcpy(class, yy_class, sizeof(*class));
        class->curr_user_count = user_count;
        class->active = 1;

        delete_conf_item(yy_conf);

        MyFree(cconf->name);            /* Allows case change of class name */
        cconf->name = yy_class_name;
      }
      else	/* Brand new class */
      {
        MyFree(yy_conf->name);          /* just in case it was allocated */
        yy_conf->name = yy_class_name;
        yy_class->active = 1;
      }
    }

    yy_class_name = NULL;
  }
}
break;
case 252:
#line 1710 "ircd_parser.y"
{
  if (ypass == 1)
  {
    MyFree(yy_class_name);
    DupString(yy_class_name, yylval.string);
  }
}
break;
case 253:
#line 1719 "ircd_parser.y"
{
  if (ypass == 1)
  {
    MyFree(yy_class_name);
    DupString(yy_class_name, yylval.string);
  }
}
break;
case 254:
#line 1728 "ircd_parser.y"
{
  if (ypass == 1)
    PingFreq(yy_class) = yyvsp[-1].number;
}
break;
case 255:
#line 1734 "ircd_parser.y"
{
  if (ypass == 1)
    PingWarning(yy_class) = yyvsp[-1].number;
}
break;
case 256:
#line 1740 "ircd_parser.y"
{
  if (ypass == 1)
    MaxPerIp(yy_class) = yyvsp[-1].number;
}
break;
case 257:
#line 1746 "ircd_parser.y"
{
  if (ypass == 1)
    ConFreq(yy_class) = yyvsp[-1].number;
}
break;
case 258:
#line 1752 "ircd_parser.y"
{
  if (ypass == 1)
    MaxTotal(yy_class) = yyvsp[-1].number;
}
break;
case 259:
#line 1758 "ircd_parser.y"
{
  if (ypass == 1)
    MaxGlobal(yy_class) = yyvsp[-1].number;
}
break;
case 260:
#line 1764 "ircd_parser.y"
{
  if (ypass == 1)
    MaxLocal(yy_class) = yyvsp[-1].number;
}
break;
case 261:
#line 1770 "ircd_parser.y"
{
  if (ypass == 1)
    MaxIdent(yy_class) = yyvsp[-1].number;
}
break;
case 262:
#line 1776 "ircd_parser.y"
{
  if (ypass == 1)
    MaxSendq(yy_class) = yyvsp[-1].number;
}
break;
case 263:
#line 1782 "ircd_parser.y"
{
  if (ypass == 1)
    CidrBitlenIPV4(yy_class) = yyvsp[-1].number;
}
break;
case 264:
#line 1788 "ircd_parser.y"
{
  if (ypass == 1)
    CidrBitlenIPV6(yy_class) = yyvsp[-1].number;
}
break;
case 265:
#line 1794 "ircd_parser.y"
{
  if (ypass == 1)
    NumberPerCidr(yy_class) = yyvsp[-1].number;
}
break;
case 266:
#line 1803 "ircd_parser.y"
{
  if (ypass == 2)
  {
    listener_address = NULL;
    listener_flags = 0;
  }
}
break;
case 267:
#line 1810 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(listener_address);
    listener_address = NULL;
  }
}
break;
case 268:
#line 1819 "ircd_parser.y"
{
  listener_flags = 0;
}
break;
case 272:
#line 1825 "ircd_parser.y"
{
  if (ypass == 2)
    listener_flags |= LISTENER_SSL;
}
break;
case 273:
#line 1829 "ircd_parser.y"
{
  if (ypass == 2)
    listener_flags |= LISTENER_HIDDEN;
}
break;
case 281:
#line 1837 "ircd_parser.y"
{ listener_flags = 0; }
break;
case 285:
#line 1842 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if ((listener_flags & LISTENER_SSL))
#ifdef HAVE_LIBCRYPTO
      if (!ServerInfo.ctx)
#endif
      {
        yyerror("SSL not available - port closed");
	break;
      }
    add_listener(yyvsp[0].number, listener_address, listener_flags);
  }
}
break;
case 286:
#line 1856 "ircd_parser.y"
{
  if (ypass == 2)
  {
    int i;

    if ((listener_flags & LISTENER_SSL))
#ifdef HAVE_LIBCRYPTO
      if (!ServerInfo.ctx)
#endif
      {
        yyerror("SSL not available - port closed");
	break;
      }

    for (i = yyvsp[-2].number; i <= yyvsp[0].number; ++i)
      add_listener(i, listener_address, listener_flags);
  }
}
break;
case 287:
#line 1876 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(listener_address);
    DupString(listener_address, yylval.string);
  }
}
break;
case 288:
#line 1885 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(listener_address);
    DupString(listener_address, yylval.string);
  }
}
break;
case 289:
#line 1897 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(CLIENT_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 290:
#line 1909 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp = NULL;
    dlink_node *ptr = NULL, *next_ptr = NULL;

    if (yy_aconf->user && yy_aconf->host)
    {
      conf_add_class_to_conf(yy_conf, class_name);
      add_conf_by_address(CONF_CLIENT, yy_aconf);
    }
    else
      delete_conf_item(yy_conf);

    /* copy over settings from first struct */
    DLINK_FOREACH_SAFE(ptr, next_ptr, col_conf_list.head)
    {
      struct AccessItem *new_aconf;
      struct ConfItem *new_conf;

      new_conf = make_conf_item(CLIENT_TYPE);
      new_aconf = map_to_conf(new_conf);

      yy_tmp = ptr->data;

      assert(yy_tmp->user && yy_tmp->host);

      if (yy_aconf->passwd != NULL)
        DupString(new_aconf->passwd, yy_aconf->passwd);
      if (yy_conf->name != NULL)
        DupString(new_conf->name, yy_conf->name);
      if (yy_aconf->passwd != NULL)
        DupString(new_aconf->passwd, yy_aconf->passwd);

      new_aconf->flags = yy_aconf->flags;
      new_aconf->port  = yy_aconf->port;

      DupString(new_aconf->user, yy_tmp->user);
      collapse(new_aconf->user);

      DupString(new_aconf->host, yy_tmp->host);
      collapse(new_aconf->host);

      conf_add_class_to_conf(new_conf, class_name);
      add_conf_by_address(CONF_CLIENT, new_aconf);
      dlinkDelete(&yy_tmp->node, &col_conf_list);
      free_collect_item(yy_tmp);
    }

    MyFree(class_name);
    class_name = NULL;
    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 310:
#line 1974 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp = NULL;
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    if (yy_aconf->user == NULL)
    {
      DupString(yy_aconf->user, userbuf);
      DupString(yy_aconf->host, hostbuf);
    }
    else
    {
      yy_tmp = MyMalloc(sizeof(struct CollectItem));

      DupString(yy_tmp->user, userbuf);
      DupString(yy_tmp->host, hostbuf);

      dlinkAdd(yy_tmp, &yy_tmp->node, &col_conf_list);
    }
  }
}
break;
case 311:
#line 2011 "ircd_parser.y"
{
  if (ypass == 2)
  {
    /* be paranoid */
    if (yy_aconf->passwd != NULL)
      memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

    MyFree(yy_aconf->passwd);
    DupString(yy_aconf->passwd, yylval.string);
  }
}
break;
case 312:
#line 2024 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_SPOOF_NOTICE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_SPOOF_NOTICE;
  }
}
break;
case 313:
#line 2035 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(class_name);
    DupString(class_name, yylval.string);
  }
}
break;
case 314:
#line 2044 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      SetConfEncrypted(yy_aconf);
    else
      ClearConfEncrypted(yy_aconf);
  }
}
break;
case 315:
#line 2055 "ircd_parser.y"
{
}
break;
case 319:
#line 2059 "ircd_parser.y"
{ not_atom = 1; }
break;
case 321:
#line 2060 "ircd_parser.y"
{ not_atom = 0; }
break;
case 323:
#line 2063 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_SPOOF_NOTICE;
    else yy_aconf->flags |= CONF_FLAGS_SPOOF_NOTICE;
  }

}
break;
case 324:
#line 2071 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NOLIMIT;
    else yy_aconf->flags |= CONF_FLAGS_NOLIMIT;
  }
}
break;
case 325:
#line 2078 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_EXEMPTKLINE;
    else yy_aconf->flags |= CONF_FLAGS_EXEMPTKLINE;
  } 
}
break;
case 326:
#line 2085 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NEED_IDENTD;
    else yy_aconf->flags |= CONF_FLAGS_NEED_IDENTD;
  }
}
break;
case 327:
#line 2092 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_CAN_FLOOD;
    else yy_aconf->flags |= CONF_FLAGS_CAN_FLOOD;
  }
}
break;
case 328:
#line 2099 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_IDLE_LINED;
    else yy_aconf->flags |= CONF_FLAGS_IDLE_LINED;
  }
}
break;
case 329:
#line 2106 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NO_TILDE;
    else yy_aconf->flags |= CONF_FLAGS_NO_TILDE;
  } 
}
break;
case 330:
#line 2113 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_EXEMPTGLINE;
    else yy_aconf->flags |= CONF_FLAGS_EXEMPTGLINE;
  } 
}
break;
case 331:
#line 2120 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_EXEMPTRESV;
    else yy_aconf->flags |= CONF_FLAGS_EXEMPTRESV;
  }
}
break;
case 332:
#line 2127 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NEED_PASSWORD;
    else yy_aconf->flags |= CONF_FLAGS_NEED_PASSWORD;
  }
}
break;
case 333:
#line 2136 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_EXEMPTKLINE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_EXEMPTKLINE;
  }
}
break;
case 334:
#line 2147 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NEED_IDENTD;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NEED_IDENTD;
  }
}
break;
case 335:
#line 2158 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NOLIMIT;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NOLIMIT;
  }
}
break;
case 336:
#line 2169 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_CAN_FLOOD;
    else
      yy_aconf->flags &= ~CONF_FLAGS_CAN_FLOOD;
  }
}
break;
case 337:
#line 2180 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NO_TILDE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NO_TILDE;
  }
}
break;
case 338:
#line 2191 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_EXEMPTGLINE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_EXEMPTGLINE;
  }
}
break;
case 339:
#line 2203 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(yy_conf->name);

    if (strlen(yylval.string) < HOSTLEN)
    {    
      DupString(yy_conf->name, yylval.string);
      yy_aconf->flags |= CONF_FLAGS_SPOOF_IP;
    }
    else
    {
      ilog(L_ERROR, "Spoofs must be less than %d..ignoring it", HOSTLEN);
      yy_conf->name = NULL;
    }
  }
}
break;
case 340:
#line 2222 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_aconf->flags |= CONF_FLAGS_REDIR;
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 341:
#line 2232 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_aconf->flags |= CONF_FLAGS_REDIR;
    yy_aconf->port = yyvsp[-1].number;
  }
}
break;
case 342:
#line 2241 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NEED_PASSWORD;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NEED_PASSWORD;
  }
}
break;
case 343:
#line 2256 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(resv_reason);
    resv_reason = NULL;
  }
}
break;
case 344:
#line 2263 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(resv_reason);
    resv_reason = NULL;
  }
}
break;
case 351:
#line 2275 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(resv_reason);
    DupString(resv_reason, yylval.string);
  }
}
break;
case 352:
#line 2284 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (IsChanPrefix(*yylval.string))
    {
      char def_reason[] = "No reason";

      create_channel_resv(yylval.string, resv_reason != NULL ? resv_reason : def_reason, 1);
    }
  }
  /* ignore it for now.. but we really should make a warning if
   * its an erroneous name --fl_ */
}
break;
case 353:
#line 2299 "ircd_parser.y"
{
  if (ypass == 2)
  {
    char def_reason[] = "No reason";

    create_nick_resv(yylval.string, resv_reason != NULL ? resv_reason : def_reason, 1);
  }
}
break;
case 354:
#line 2312 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(ULINE_TYPE);
    yy_match_item = map_to_conf(yy_conf);
    yy_match_item->action = SHARED_ALL;
  }
}
break;
case 355:
#line 2320 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = NULL;
  }
}
break;
case 362:
#line 2331 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 363:
#line 2340 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    DupString(yy_match_item->user, userbuf);
    DupString(yy_match_item->host, hostbuf);
  }
}
break;
case 364:
#line 2362 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action = 0;
}
break;
case 368:
#line 2369 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_KLINE;
}
break;
case 369:
#line 2373 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_TKLINE;
}
break;
case 370:
#line 2377 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_UNKLINE;
}
break;
case 371:
#line 2381 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_XLINE;
}
break;
case 372:
#line 2385 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_TXLINE;
}
break;
case 373:
#line 2389 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_UNXLINE;
}
break;
case 374:
#line 2393 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_RESV;
}
break;
case 375:
#line 2397 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_TRESV;
}
break;
case 376:
#line 2401 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_UNRESV;
}
break;
case 377:
#line 2405 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_LOCOPS;
}
break;
case 378:
#line 2409 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action |= SHARED_USERMODE;
}
break;
case 379:
#line 2413 "ircd_parser.y"
{
  if (ypass == 2)
    yy_match_item->action = SHARED_ALL;
}
break;
case 380:
#line 2422 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(CLUSTER_TYPE);
    yy_conf->flags = SHARED_ALL;
  }
}
break;
case 381:
#line 2429 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yy_conf->name == NULL)
      DupString(yy_conf->name, "*");
    yy_conf = NULL;
  }
}
break;
case 387:
#line 2442 "ircd_parser.y"
{
  if (ypass == 2)
    DupString(yy_conf->name, yylval.string);
}
break;
case 388:
#line 2448 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags = 0;
}
break;
case 392:
#line 2455 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_KLINE;
}
break;
case 393:
#line 2459 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_TKLINE;
}
break;
case 394:
#line 2463 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_UNKLINE;
}
break;
case 395:
#line 2467 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_XLINE;
}
break;
case 396:
#line 2471 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_TXLINE;
}
break;
case 397:
#line 2475 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_UNXLINE;
}
break;
case 398:
#line 2479 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_RESV;
}
break;
case 399:
#line 2483 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_TRESV;
}
break;
case 400:
#line 2487 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_UNRESV;
}
break;
case 401:
#line 2491 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags |= SHARED_LOCOPS;
}
break;
case 402:
#line 2495 "ircd_parser.y"
{
  if (ypass == 2)
    yy_conf->flags = SHARED_ALL;
}
break;
case 403:
#line 2504 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(SERVER_TYPE);
    yy_aconf = (struct AccessItem *)map_to_conf(yy_conf);
    yy_aconf->passwd = NULL;
    /* defaults */
    yy_aconf->port = PORTNUM;

    if (ConfigFileEntry.burst_away)
      yy_aconf->flags = CONF_FLAGS_BURST_AWAY;
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 404:
#line 2522 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct CollectItem *yy_hconf=NULL;
    struct CollectItem *yy_lconf=NULL;
    dlink_node *ptr;
    dlink_node *next_ptr;
#ifdef HAVE_LIBCRYPTO
    if (yy_aconf->host &&
	((yy_aconf->passwd && yy_aconf->spasswd) ||
	 (yy_aconf->rsa_public_key && IsConfCryptLink(yy_aconf))))
#else /* !HAVE_LIBCRYPTO */
      if (yy_aconf->host && !IsConfCryptLink(yy_aconf) && 
	  yy_aconf->passwd && yy_aconf->spasswd)
#endif /* !HAVE_LIBCRYPTO */
	{
	  if (conf_add_server(yy_conf, class_name) == -1)
	  {
	    delete_conf_item(yy_conf);
	    yy_conf = NULL;
	    yy_aconf = NULL;
	  }
	}
	else
	{
	  /* Even if yy_conf ->name is NULL
	   * should still unhook any hub/leaf confs still pending
	   */
	  unhook_hub_leaf_confs();

	  if (yy_conf->name != NULL)
	  {
#ifndef HAVE_LIBCRYPTO
	    if (IsConfCryptLink(yy_aconf))
	      yyerror("Ignoring connect block -- no OpenSSL support");
#else
	    if (IsConfCryptLink(yy_aconf) && !yy_aconf->rsa_public_key)
	      yyerror("Ignoring connect block -- missing key");
#endif
	    if (yy_aconf->host == NULL)
	      yyerror("Ignoring connect block -- missing host");
	    else if (!IsConfCryptLink(yy_aconf) && 
		    (!yy_aconf->passwd || !yy_aconf->spasswd))
              yyerror("Ignoring connect block -- missing password");
	  }


          /* XXX
           * This fixes a try_connections() core (caused by invalid class_ptr
           * pointers) reported by metalrock. That's an ugly fix, but there
           * is currently no better way. The entire config subsystem needs an
           * rewrite ASAP. make_conf_item() shouldn't really add things onto
           * a doubly linked list immediately without any sanity checks!  -Michael
           */
          delete_conf_item(yy_conf);

          yy_aconf = NULL;
	  yy_conf = NULL;
	}

      /*
       * yy_conf is still pointing at the server that is having
       * a connect block built for it. This means, y_aconf->name 
       * points to the actual irc name this server will be known as.
       * Now this new server has a set or even just one hub_mask (or leaf_mask)
       * given in the link list at yy_hconf. Fill in the HUB confs
       * from this link list now.
       */        
      DLINK_FOREACH_SAFE(ptr, next_ptr, hub_conf_list.head)
      {
	struct ConfItem *new_hub_conf;
	struct MatchItem *match_item;

	yy_hconf = ptr->data;

	/* yy_conf == NULL is a fatal error for this connect block! */
	if ((yy_conf != NULL) && (yy_conf->name != NULL))
	{
	  new_hub_conf = make_conf_item(HUB_TYPE);
	  match_item = (struct MatchItem *)map_to_conf(new_hub_conf);
	  DupString(new_hub_conf->name, yy_conf->name);
	  if (yy_hconf->user != NULL)
	    DupString(match_item->user, yy_hconf->user);
	  else
	    DupString(match_item->user, "*");
	  if (yy_hconf->host != NULL)
	    DupString(match_item->host, yy_hconf->host);
	  else
	    DupString(match_item->host, "*");
	}
	dlinkDelete(&yy_hconf->node, &hub_conf_list);
	free_collect_item(yy_hconf);
      }

      /* Ditto for the LEAF confs */

      DLINK_FOREACH_SAFE(ptr, next_ptr, leaf_conf_list.head)
      {
	struct ConfItem *new_leaf_conf;
	struct MatchItem *match_item;

	yy_lconf = ptr->data;

	if ((yy_conf != NULL) && (yy_conf->name != NULL))
	{
	  new_leaf_conf = make_conf_item(LEAF_TYPE);
	  match_item = (struct MatchItem *)map_to_conf(new_leaf_conf);
	  DupString(new_leaf_conf->name, yy_conf->name);
	  if (yy_lconf->user != NULL)
	    DupString(match_item->user, yy_lconf->user);
	  else
	    DupString(match_item->user, "*");
	  if (yy_lconf->host != NULL)
	    DupString(match_item->host, yy_lconf->host);
	  else
	    DupString(match_item->host, "*");
	}
	dlinkDelete(&yy_lconf->node, &leaf_conf_list);
	free_collect_item(yy_lconf);
      }
      MyFree(class_name);
      class_name = NULL;
      yy_conf = NULL;
      yy_aconf = NULL;
  }
}
break;
case 429:
#line 2661 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yy_conf->name != NULL)
      yyerror("Multiple connect name entry");

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 430:
#line 2673 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yy_conf->name != NULL)
      yyerror("Multiple connect name entry");

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 431:
#line 2685 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(yy_aconf->host);
    DupString(yy_aconf->host, yylval.string);
  }
}
break;
case 432:
#line 2694 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct addrinfo hints, *res;

    memset(&hints, 0, sizeof(hints));

    hints.ai_family   = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;

    if (irc_getaddrinfo(yylval.string, NULL, &hints, &res))
      ilog(L_ERROR, "Invalid netmask for server vhost(%s)", yylval.string);
    else
    {
      assert(res != NULL);

      memcpy(&yy_aconf->my_ipnum, res->ai_addr, res->ai_addrlen);
      yy_aconf->my_ipnum.ss.ss_family = res->ai_family;
      yy_aconf->my_ipnum.ss_len = res->ai_addrlen;
      irc_freeaddrinfo(res);
    }
  }
}
break;
case 433:
#line 2720 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yyvsp[-1].string[0] == ':')
      yyerror("Server passwords cannot begin with a colon");
    else if (strchr(yyvsp[-1].string, ' ') != NULL)
      yyerror("Server passwords cannot contain spaces");
    else {
      if (yy_aconf->spasswd != NULL)
        memset(yy_aconf->spasswd, 0, strlen(yy_aconf->spasswd));

      MyFree(yy_aconf->spasswd);
      DupString(yy_aconf->spasswd, yylval.string);
    }
  }
}
break;
case 434:
#line 2738 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yyvsp[-1].string[0] == ':')
      yyerror("Server passwords cannot begin with a colon");
    else if (strchr(yyvsp[-1].string, ' ') != NULL)
      yyerror("Server passwords cannot contain spaces");
    else {
      if (yy_aconf->passwd != NULL)
        memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

      MyFree(yy_aconf->passwd);
      DupString(yy_aconf->passwd, yylval.string);
    }
  }
}
break;
case 435:
#line 2756 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->port = yyvsp[-1].number;
}
break;
case 436:
#line 2762 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->aftype = AF_INET;
}
break;
case 437:
#line 2766 "ircd_parser.y"
{
#ifdef IPV6
  if (ypass == 2)
    yy_aconf->aftype = AF_INET6;
#endif
}
break;
case 438:
#line 2774 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(yy_aconf->fakename);
    DupString(yy_aconf->fakename, yylval.string);
  }
}
break;
case 439:
#line 2783 "ircd_parser.y"
{
}
break;
case 443:
#line 2787 "ircd_parser.y"
{ not_atom = 1; }
break;
case 445:
#line 2788 "ircd_parser.y"
{ not_atom = 0; }
break;
case 447:
#line 2791 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom)ClearConfLazyLink(yy_aconf);
    else SetConfLazyLink(yy_aconf);
  }
}
break;
case 448:
#line 2798 "ircd_parser.y"
{
  if (ypass == 2)
#ifndef HAVE_LIBZ
    yyerror("Ignoring flags = compressed; -- no zlib support");
#else
 {
   if (not_atom)ClearConfCompressed(yy_aconf);
   else SetConfCompressed(yy_aconf);
 }
#endif
}
break;
case 449:
#line 2809 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom)ClearConfCryptLink(yy_aconf);
    else SetConfCryptLink(yy_aconf);
  }
}
break;
case 450:
#line 2816 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom)ClearConfAllowAutoConn(yy_aconf);
    else SetConfAllowAutoConn(yy_aconf);
  }
}
break;
case 451:
#line 2823 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom)ClearConfAwayBurst(yy_aconf);
    else SetConfAwayBurst(yy_aconf);
  }
}
break;
case 452:
#line 2830 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (not_atom)ClearConfTopicBurst(yy_aconf);
    else SetConfTopicBurst(yy_aconf);
  }
}
break;
case 453:
#line 2840 "ircd_parser.y"
{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    BIO *file;

    if (yy_aconf->rsa_public_key != NULL)
    {
      RSA_free(yy_aconf->rsa_public_key);
      yy_aconf->rsa_public_key = NULL;
    }

    if (yy_aconf->rsa_public_key_file != NULL)
    {
      MyFree(yy_aconf->rsa_public_key_file);
      yy_aconf->rsa_public_key_file = NULL;
    }

    DupString(yy_aconf->rsa_public_key_file, yylval.string);

    if ((file = BIO_new_file(yylval.string, "r")) == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- file doesn't exist");
      break;
    }

    yy_aconf->rsa_public_key = (RSA *)PEM_read_bio_RSA_PUBKEY(file, NULL, 0, NULL);

    if (yy_aconf->rsa_public_key == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- Key invalid; check key syntax.");
      break;
    }
      
    BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);
  }
#endif /* HAVE_LIBCRYPTO */
}
break;
case 454:
#line 2881 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_ENCRYPTED;
    else
      yy_aconf->flags &= ~CONF_FLAGS_ENCRYPTED;
  }
}
break;
case 455:
#line 2892 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_CRYPTLINK;
    else
      yy_aconf->flags &= ~CONF_FLAGS_CRYPTLINK;
  }
}
break;
case 456:
#line 2903 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
#ifndef HAVE_LIBZ
      yyerror("Ignoring compressed=yes; -- no zlib support");
#else
      yy_aconf->flags |= CONF_FLAGS_COMPRESSED;
#endif
    else
      yy_aconf->flags &= ~CONF_FLAGS_COMPRESSED;
  }
}
break;
case 457:
#line 2918 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_ALLOW_AUTO_CONN;
    else
      yy_aconf->flags &= ~CONF_FLAGS_ALLOW_AUTO_CONN;
  }
}
break;
case 458:
#line 2929 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.number)
      SetConfTopicBurst(yy_aconf);
    else
      ClearConfTopicBurst(yy_aconf);
  }
}
break;
case 459:
#line 2940 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp;

    yy_tmp = (struct CollectItem *)MyMalloc(sizeof(struct CollectItem));
    DupString(yy_tmp->host, yylval.string);
    DupString(yy_tmp->user, "*");
    dlinkAdd(yy_tmp, &yy_tmp->node, &hub_conf_list);
  }
}
break;
case 460:
#line 2953 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp;

    yy_tmp = (struct CollectItem *)MyMalloc(sizeof(struct CollectItem));
    DupString(yy_tmp->host, yylval.string);
    DupString(yy_tmp->user, "*");
    dlinkAdd(yy_tmp, &yy_tmp->node, &leaf_conf_list);
  }
}
break;
case 461:
#line 2966 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(class_name);
    DupString(class_name, yylval.string);
  }
}
break;
case 462:
#line 2975 "ircd_parser.y"
{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    struct EncCapability *ecap;
    const char *cipher_name;
    int found = 0;

    yy_aconf->cipher_preference = NULL;
    cipher_name = yylval.string;

    for (ecap = CipherTable; ecap->name; ecap++)
    {
      if ((irccmp(ecap->name, cipher_name) == 0) &&
          (ecap->cap & CAP_ENC_MASK))
      {
        yy_aconf->cipher_preference = ecap;
        found = 1;
        break;
      }
    }

    if (!found)
      yyerror("Invalid cipher");
  }
#else
  if (ypass == 2)
    yyerror("Ignoring cipher_preference -- no OpenSSL support");
#endif
}
break;
case 463:
#line 3010 "ircd_parser.y"
{
  if (ypass == 2)
  {
    userbuf[0] = hostbuf[0] = reasonbuf[0] = '\0';
    regex_ban = 0;
  }
}
break;
case 464:
#line 3017 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (userbuf[0] && hostbuf[0])
    {
      if (regex_ban)
      {
        pcre *exp_user = NULL;
        pcre *exp_host = NULL;
        const char *errptr = NULL;

        if (!(exp_user = ircd_pcre_compile(userbuf, &errptr)) ||
            !(exp_host = ircd_pcre_compile(hostbuf, &errptr)))
        {
          ilog(L_ERROR, "Failed to add regular expression based K-Line: %s",
               errptr);
          break;
        }

        yy_conf = make_conf_item(RKLINE_TYPE);
        yy_aconf = map_to_conf(yy_conf);

        yy_aconf->regexuser = exp_user;
        yy_aconf->regexhost = exp_host;

        DupString(yy_aconf->user, userbuf);
        DupString(yy_aconf->host, hostbuf);

        if (reasonbuf[0])
          DupString(yy_aconf->reason, reasonbuf);
        else
          DupString(yy_aconf->reason, "No reason");
      }
      else
      {
        yy_conf = make_conf_item(KLINE_TYPE);
        yy_aconf = map_to_conf(yy_conf);

        DupString(yy_aconf->user, userbuf);
        DupString(yy_aconf->host, hostbuf);

        if (reasonbuf[0])
          DupString(yy_aconf->reason, reasonbuf);
        else
          DupString(yy_aconf->reason, "No reason");
        add_conf_by_address(CONF_KILL, yy_aconf);
      }
    }
    else
      delete_conf_item(yy_conf);

    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 465:
#line 3074 "ircd_parser.y"
{
}
break;
case 469:
#line 3079 "ircd_parser.y"
{
  if (ypass == 2)
    regex_ban = 1;
}
break;
case 476:
#line 3088 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);
  }
}
break;
case 477:
#line 3107 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(reasonbuf, yylval.string, sizeof(reasonbuf));
}
break;
case 478:
#line 3116 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(DLINE_TYPE);
    yy_aconf = map_to_conf(yy_conf);
    /* default reason */
    DupString(yy_aconf->reason, "No reason");
  }
}
break;
case 479:
#line 3125 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yy_aconf->host && parse_netmask(yy_aconf->host, NULL, NULL) != HM_HOST)
      add_conf_by_address(CONF_DLINE, yy_aconf);
    else
      delete_conf_item(yy_conf);
    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 485:
#line 3141 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(yy_aconf->host);
    DupString(yy_aconf->host, yylval.string);
  }
}
break;
case 486:
#line 3150 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(yy_aconf->reason);
    DupString(yy_aconf->reason, yylval.string);
  }
}
break;
case 492:
#line 3167 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (yylval.string[0] && parse_netmask(yylval.string, NULL, NULL) != HM_HOST)
    {
      yy_conf = make_conf_item(EXEMPTDLINE_TYPE);
      yy_aconf = map_to_conf(yy_conf);
      DupString(yy_aconf->host, yylval.string);

      add_conf_by_address(CONF_EXEMPTDLINE, yy_aconf);

      yy_conf = NULL;
      yy_aconf = NULL;
    }
  }
}
break;
case 493:
#line 3188 "ircd_parser.y"
{
  if (ypass == 2)
  {
    regex_ban = 0;
    reasonbuf[0] = gecos_name[0] = '\0';
  }
}
break;
case 494:
#line 3195 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (gecos_name[0])
    {
      if (regex_ban)
      {
        pcre *exp_p = NULL;
        const char *errptr = NULL;

        if (!(exp_p = ircd_pcre_compile(gecos_name, &errptr)))
        {
          ilog(L_ERROR, "Failed to add regular expression based X-Line: %s",
               errptr);
          break;
        }

        yy_conf = make_conf_item(RXLINE_TYPE);
        yy_conf->regexpname = exp_p;
      }
      else
        yy_conf = make_conf_item(XLINE_TYPE);

      yy_match_item = map_to_conf(yy_conf);
      DupString(yy_conf->name, gecos_name);

      if (reasonbuf[0])
        DupString(yy_match_item->reason, reasonbuf);
      else
        DupString(yy_match_item->reason, "No reason");
    }
  }
}
break;
case 495:
#line 3230 "ircd_parser.y"
{
}
break;
case 499:
#line 3235 "ircd_parser.y"
{
  if (ypass == 2)
    regex_ban = 1;
}
break;
case 506:
#line 3244 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(gecos_name, yylval.string, sizeof(gecos_name));
}
break;
case 507:
#line 3250 "ircd_parser.y"
{
  if (ypass == 2)
    strlcpy(reasonbuf, yylval.string, sizeof(reasonbuf));
}
break;
case 568:
#line 3295 "ircd_parser.y"
{
  ConfigFileEntry.gline_min_cidr = yyvsp[-1].number;
}
break;
case 569:
#line 3300 "ircd_parser.y"
{
  ConfigFileEntry.gline_min_cidr6 = yyvsp[-1].number;
}
break;
case 570:
#line 3305 "ircd_parser.y"
{
  ConfigFileEntry.burst_away = yylval.number;
}
break;
case 571:
#line 3310 "ircd_parser.y"
{
  ConfigFileEntry.use_whois_actually = yylval.number;
}
break;
case 572:
#line 3315 "ircd_parser.y"
{
  GlobalSetOptions.rejecttime = yylval.number;
}
break;
case 573:
#line 3320 "ircd_parser.y"
{
  ConfigFileEntry.tkline_expire_notices = yylval.number;
}
break;
case 574:
#line 3325 "ircd_parser.y"
{
  ConfigFileEntry.kill_chase_time_limit = yyvsp[-1].number;
}
break;
case 575:
#line 3330 "ircd_parser.y"
{
  ConfigFileEntry.hide_spoof_ips = yylval.number;
}
break;
case 576:
#line 3335 "ircd_parser.y"
{
  ConfigFileEntry.ignore_bogus_ts = yylval.number;
}
break;
case 577:
#line 3340 "ircd_parser.y"
{
  ConfigFileEntry.disable_remote = yylval.number;
}
break;
case 578:
#line 3345 "ircd_parser.y"
{
  ConfigFileEntry.failed_oper_notice = yylval.number;
}
break;
case 579:
#line 3350 "ircd_parser.y"
{
  ConfigFileEntry.anti_nick_flood = yylval.number;
}
break;
case 580:
#line 3355 "ircd_parser.y"
{
  ConfigFileEntry.max_nick_time = yyvsp[-1].number; 
}
break;
case 581:
#line 3360 "ircd_parser.y"
{
  ConfigFileEntry.max_nick_changes = yyvsp[-1].number;
}
break;
case 582:
#line 3365 "ircd_parser.y"
{
  ConfigFileEntry.max_accept = yyvsp[-1].number;
}
break;
case 583:
#line 3370 "ircd_parser.y"
{
  ConfigFileEntry.anti_spam_exit_message_time = yyvsp[-1].number;
}
break;
case 584:
#line 3375 "ircd_parser.y"
{
  ConfigFileEntry.ts_warn_delta = yyvsp[-1].number;
}
break;
case 585:
#line 3380 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigFileEntry.ts_max_delta = yyvsp[-1].number;
}
break;
case 586:
#line 3386 "ircd_parser.y"
{
  if ((yyvsp[-1].number > 0) && ypass == 1)
  {
    ilog(L_CRIT, "You haven't read your config file properly.");
    ilog(L_CRIT, "There is a line in the example conf that will kill your server if not removed.");
    ilog(L_CRIT, "Consider actually reading/editing the conf file, and removing this line.");
    exit(0);
  }
}
break;
case 587:
#line 3397 "ircd_parser.y"
{
  ConfigFileEntry.kline_with_reason = yylval.number;
}
break;
case 588:
#line 3402 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.kline_reason);
    DupString(ConfigFileEntry.kline_reason, yylval.string);
  }
}
break;
case 589:
#line 3411 "ircd_parser.y"
{
  ConfigFileEntry.invisible_on_connect = yylval.number;
}
break;
case 590:
#line 3416 "ircd_parser.y"
{
#ifdef HAVE_LIBCRYPTO
  ConfigFileEntry.mode_z = yylval.number;
#endif
}
break;
case 591:
#line 3423 "ircd_parser.y"
{
  ConfigFileEntry.warn_no_nline = yylval.number;
}
break;
case 592:
#line 3428 "ircd_parser.y"
{
  ConfigFileEntry.stats_e_disabled = yylval.number;
}
break;
case 593:
#line 3433 "ircd_parser.y"
{
  ConfigFileEntry.stats_o_oper_only = yylval.number;
}
break;
case 594:
#line 3438 "ircd_parser.y"
{
  ConfigFileEntry.stats_P_oper_only = yylval.number;
}
break;
case 595:
#line 3443 "ircd_parser.y"
{
  ConfigFileEntry.stats_k_oper_only = 2 * yylval.number;
}
break;
case 596:
#line 3446 "ircd_parser.y"
{
  ConfigFileEntry.stats_k_oper_only = 1;
}
break;
case 597:
#line 3451 "ircd_parser.y"
{
  ConfigFileEntry.stats_i_oper_only = 2 * yylval.number;
}
break;
case 598:
#line 3454 "ircd_parser.y"
{
  ConfigFileEntry.stats_i_oper_only = 1;
}
break;
case 599:
#line 3459 "ircd_parser.y"
{
  ConfigFileEntry.pace_wait = yyvsp[-1].number;
}
break;
case 600:
#line 3464 "ircd_parser.y"
{
  ConfigFileEntry.caller_id_wait = yyvsp[-1].number;
}
break;
case 601:
#line 3469 "ircd_parser.y"
{
  ConfigFileEntry.opers_bypass_callerid = yylval.number;
}
break;
case 602:
#line 3474 "ircd_parser.y"
{
  ConfigFileEntry.pace_wait_simple = yyvsp[-1].number;
}
break;
case 603:
#line 3479 "ircd_parser.y"
{
  ConfigFileEntry.short_motd = yylval.number;
}
break;
case 604:
#line 3484 "ircd_parser.y"
{
  ConfigFileEntry.no_oper_flood = yylval.number;
}
break;
case 605:
#line 3489 "ircd_parser.y"
{
  ConfigFileEntry.true_no_oper_flood = yylval.number;
}
break;
case 606:
#line 3494 "ircd_parser.y"
{
  ConfigFileEntry.oper_pass_resv = yylval.number;
}
break;
case 607:
#line 3499 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if (strlen(yylval.string) > LOCALE_LENGTH-2)
      yylval.string[LOCALE_LENGTH-1] = '\0';

    set_locale(yylval.string);
  }
}
break;
case 608:
#line 3510 "ircd_parser.y"
{
  ConfigFileEntry.idletime = yyvsp[-1].number;
}
break;
case 609:
#line 3515 "ircd_parser.y"
{
  ConfigFileEntry.dots_in_ident = yyvsp[-1].number;
}
break;
case 610:
#line 3520 "ircd_parser.y"
{
  ConfigFileEntry.max_targets = yyvsp[-1].number;
}
break;
case 611:
#line 3525 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.servlink_path);
    DupString(ConfigFileEntry.servlink_path, yylval.string);
  }
}
break;
case 612:
#line 3534 "ircd_parser.y"
{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    struct EncCapability *ecap;
    const char *cipher_name;
    int found = 0;

    ConfigFileEntry.default_cipher_preference = NULL;
    cipher_name = yylval.string;

    for (ecap = CipherTable; ecap->name; ecap++)
    {
      if ((irccmp(ecap->name, cipher_name) == 0) &&
          (ecap->cap & CAP_ENC_MASK))
      {
        ConfigFileEntry.default_cipher_preference = ecap;
        found = 1;
        break;
      }
    }

    if (!found)
      yyerror("Invalid cipher");
  }
#else
  if (ypass == 2)
    yyerror("Ignoring default_cipher_preference -- no OpenSSL support");
#endif
}
break;
case 613:
#line 3566 "ircd_parser.y"
{
  if (ypass == 2)
  {
    ConfigFileEntry.compression_level = yyvsp[-1].number;
#ifndef HAVE_LIBZ
    yyerror("Ignoring compression_level -- no zlib support");
#else
    if ((ConfigFileEntry.compression_level < 1) ||
        (ConfigFileEntry.compression_level > 9))
    {
      yyerror("Ignoring invalid compression_level, using default");
      ConfigFileEntry.compression_level = 0;
    }
#endif
  }
}
break;
case 614:
#line 3584 "ircd_parser.y"
{
  ConfigFileEntry.use_egd = yylval.number;
}
break;
case 615:
#line 3589 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.egdpool_path);
    DupString(ConfigFileEntry.egdpool_path, yylval.string);
  }
}
break;
case 616:
#line 3598 "ircd_parser.y"
{
  ConfigFileEntry.ping_cookie = yylval.number;
}
break;
case 617:
#line 3603 "ircd_parser.y"
{
  ConfigFileEntry.disable_auth = yylval.number;
}
break;
case 618:
#line 3608 "ircd_parser.y"
{
  ConfigFileEntry.throttle_time = yylval.number;
}
break;
case 619:
#line 3613 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes = 0;
}
break;
case 623:
#line 3619 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_BOTS;
}
break;
case 624:
#line 3622 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_CCONN;
}
break;
case 625:
#line 3625 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_CCONN_FULL;
}
break;
case 626:
#line 3628 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_DEAF;
}
break;
case 627:
#line 3631 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_DEBUG;
}
break;
case 628:
#line 3634 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_FULL;
}
break;
case 629:
#line 3637 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_SKILL;
}
break;
case 630:
#line 3640 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_NCHANGE;
}
break;
case 631:
#line 3643 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_REJ;
}
break;
case 632:
#line 3646 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_UNAUTH;
}
break;
case 633:
#line 3649 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_SPY;
}
break;
case 634:
#line 3652 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_EXTERNAL;
}
break;
case 635:
#line 3655 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_OPERWALL;
}
break;
case 636:
#line 3658 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_SERVNOTICE;
}
break;
case 637:
#line 3661 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_INVISIBLE;
}
break;
case 638:
#line 3664 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_WALLOP;
}
break;
case 639:
#line 3667 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_SOFTCALLERID;
}
break;
case 640:
#line 3670 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_CALLERID;
}
break;
case 641:
#line 3673 "ircd_parser.y"
{
  ConfigFileEntry.oper_umodes |= UMODE_LOCOPS;
}
break;
case 642:
#line 3678 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes = 0;
}
break;
case 646:
#line 3684 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_BOTS;
}
break;
case 647:
#line 3687 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_CCONN;
}
break;
case 648:
#line 3690 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_CCONN_FULL;
}
break;
case 649:
#line 3693 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_DEAF;
}
break;
case 650:
#line 3696 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_DEBUG;
}
break;
case 651:
#line 3699 "ircd_parser.y"
{ 
  ConfigFileEntry.oper_only_umodes |= UMODE_FULL;
}
break;
case 652:
#line 3702 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_SKILL;
}
break;
case 653:
#line 3705 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_NCHANGE;
}
break;
case 654:
#line 3708 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_REJ;
}
break;
case 655:
#line 3711 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_UNAUTH;
}
break;
case 656:
#line 3714 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_SPY;
}
break;
case 657:
#line 3717 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_EXTERNAL;
}
break;
case 658:
#line 3720 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_OPERWALL;
}
break;
case 659:
#line 3723 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_SERVNOTICE;
}
break;
case 660:
#line 3726 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_INVISIBLE;
}
break;
case 661:
#line 3729 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_WALLOP;
}
break;
case 662:
#line 3732 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_SOFTCALLERID;
}
break;
case 663:
#line 3735 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_CALLERID;
}
break;
case 664:
#line 3738 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_LOCOPS;
}
break;
case 665:
#line 3741 "ircd_parser.y"
{
  ConfigFileEntry.oper_only_umodes |= UMODE_SNOOP;
}
break;
case 666:
#line 3746 "ircd_parser.y"
{
  ConfigFileEntry.min_nonwildcard = yyvsp[-1].number;
}
break;
case 667:
#line 3751 "ircd_parser.y"
{
  ConfigFileEntry.min_nonwildcard_simple = yyvsp[-1].number;
}
break;
case 668:
#line 3756 "ircd_parser.y"
{
  ConfigFileEntry.default_floodcount = yyvsp[-1].number;
}
break;
case 669:
#line 3761 "ircd_parser.y"
{
  ConfigFileEntry.client_flood = yyvsp[-1].number;
}
break;
case 670:
#line 3766 "ircd_parser.y"
{
  ConfigFileEntry.dot_in_ip6_addr = yylval.number;
}
break;
case 671:
#line 3774 "ircd_parser.y"
{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(GDENY_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
}
break;
case 672:
#line 3781 "ircd_parser.y"
{
  if (ypass == 2)
  {
    /*
     * since we re-allocate yy_conf/yy_aconf after the end of action=, at the
     * end we will have one extra, so we should free it.
     */
    if (yy_conf->name == NULL || yy_aconf->user == NULL)
    {
      delete_conf_item(yy_conf);
      yy_conf = NULL;
      yy_aconf = NULL;
    }
  }
}
break;
case 682:
#line 3807 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigFileEntry.glines = yylval.number;
}
break;
case 683:
#line 3813 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigFileEntry.gline_time = yyvsp[-1].number;
}
break;
case 684:
#line 3819 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigFileEntry.gline_logging = 0;
}
break;
case 688:
#line 3825 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigFileEntry.gline_logging |= GDENY_REJECT;
}
break;
case 689:
#line 3829 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigFileEntry.gline_logging |= GDENY_BLOCK;
}
break;
case 690:
#line 3835 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    if (yy_aconf->user == NULL)
    {
      DupString(yy_aconf->user, userbuf);
      DupString(yy_aconf->host, hostbuf);
    }
    else
    {
      struct CollectItem *yy_tmp = MyMalloc(sizeof(struct CollectItem));

      DupString(yy_tmp->user, userbuf);
      DupString(yy_tmp->host, hostbuf);

      dlinkAdd(yy_tmp, &yy_tmp->node, &col_conf_list);
    }
  }
}
break;
case 691:
#line 3869 "ircd_parser.y"
{
  if (ypass == 2)  
  {
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 692:
#line 3878 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->flags = 0;
}
break;
case 693:
#line 3882 "ircd_parser.y"
{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp = NULL;
    dlink_node *ptr, *next_ptr;

    DLINK_FOREACH_SAFE(ptr, next_ptr, col_conf_list.head)
    {
      struct AccessItem *new_aconf;
      struct ConfItem *new_conf;

      yy_tmp = ptr->data;
      new_conf = make_conf_item(GDENY_TYPE);
      new_aconf = map_to_conf(new_conf);

      new_aconf->flags = yy_aconf->flags;

      if (yy_conf->name != NULL)
        DupString(new_conf->name, yy_conf->name);
      else
        DupString(new_conf->name, "*");
      if (yy_aconf->user != NULL)
         DupString(new_aconf->user, yy_tmp->user);
      else   
        DupString(new_aconf->user, "*");
      if (yy_aconf->host != NULL)
        DupString(new_aconf->host, yy_tmp->host);
      else
        DupString(new_aconf->host, "*");

      dlinkDelete(&yy_tmp->node, &col_conf_list);
    }

    /*
     * In case someone has fed us with more than one action= after user/name
     * which would leak memory  -Michael
     */
    if (yy_conf->name == NULL || yy_aconf->user == NULL)
      delete_conf_item(yy_conf);

    yy_conf = make_conf_item(GDENY_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
}
break;
case 696:
#line 3929 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->flags |= GDENY_REJECT;
}
break;
case 697:
#line 3933 "ircd_parser.y"
{
  if (ypass == 2)
    yy_aconf->flags |= GDENY_BLOCK;
}
break;
case 720:
#line 3957 "ircd_parser.y"
{
  ConfigChannel.disable_fake_channels = yylval.number;
}
break;
case 721:
#line 3962 "ircd_parser.y"
{
  ConfigChannel.restrict_channels = yylval.number;
}
break;
case 722:
#line 3967 "ircd_parser.y"
{
  ConfigChannel.disable_local_channels = yylval.number;
}
break;
case 723:
#line 3972 "ircd_parser.y"
{
  ConfigChannel.use_except = yylval.number;
}
break;
case 724:
#line 3977 "ircd_parser.y"
{
  ConfigChannel.use_invex = yylval.number;
}
break;
case 725:
#line 3982 "ircd_parser.y"
{
  ConfigChannel.use_knock = yylval.number;
}
break;
case 726:
#line 3987 "ircd_parser.y"
{
  ConfigChannel.knock_delay = yyvsp[-1].number;
}
break;
case 727:
#line 3992 "ircd_parser.y"
{
  ConfigChannel.knock_delay_channel = yyvsp[-1].number;
}
break;
case 728:
#line 3997 "ircd_parser.y"
{
  ConfigChannel.max_chans_per_user = yyvsp[-1].number;
}
break;
case 729:
#line 4002 "ircd_parser.y"
{
  ConfigChannel.quiet_on_ban = yylval.number;
}
break;
case 730:
#line 4007 "ircd_parser.y"
{
  ConfigChannel.max_bans = yyvsp[-1].number;
}
break;
case 731:
#line 4012 "ircd_parser.y"
{
  ConfigChannel.default_split_user_count = yyvsp[-1].number;
}
break;
case 732:
#line 4017 "ircd_parser.y"
{
  ConfigChannel.default_split_server_count = yyvsp[-1].number;
}
break;
case 733:
#line 4022 "ircd_parser.y"
{
  ConfigChannel.no_create_on_split = yylval.number;
}
break;
case 734:
#line 4027 "ircd_parser.y"
{
  ConfigChannel.no_join_on_split = yylval.number;
}
break;
case 735:
#line 4032 "ircd_parser.y"
{
  ConfigChannel.burst_topicwho = yylval.number;
}
break;
case 736:
#line 4037 "ircd_parser.y"
{
  GlobalSetOptions.joinfloodcount = yylval.number;
}
break;
case 737:
#line 4042 "ircd_parser.y"
{
  GlobalSetOptions.joinfloodtime = yylval.number;
}
break;
case 749:
#line 4061 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigServerHide.flatten_links = yylval.number;
}
break;
case 750:
#line 4067 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigServerHide.hide_servers = yylval.number;
}
break;
case 751:
#line 4073 "ircd_parser.y"
{
  if (ypass == 2)
  {
    MyFree(ConfigServerHide.hidden_name);
    DupString(ConfigServerHide.hidden_name, yylval.string);
  }
}
break;
case 752:
#line 4082 "ircd_parser.y"
{
  if (ypass == 2)
  {
    if ((yyvsp[-1].number > 0) && ConfigServerHide.links_disabled == 1)
    {
      eventAddIsh("write_links_file", write_links_file, NULL, yyvsp[-1].number);
      ConfigServerHide.links_disabled = 0;
    }

    ConfigServerHide.links_delay = yyvsp[-1].number;
  }
}
break;
case 753:
#line 4096 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigServerHide.hidden = yylval.number;
}
break;
case 754:
#line 4102 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigServerHide.disable_hidden = yylval.number;
}
break;
case 755:
#line 4108 "ircd_parser.y"
{
  if (ypass == 2)
    ConfigServerHide.hide_server_ips = yylval.number;
}
break;
#line 6536 "y.tab.c"
    }
    yyssp -= yym;
    yystate = *yyssp;
    yyvsp -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yyssp = YYFINAL;
        *++yyvsp = yyval;
        if (yychar < 0)
        {
            if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
            if (yydebug)
            {
                yys = 0;
                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
                if (!yys) yys = "illegal-symbol";
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == 0) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yyssp, yystate);
#endif
    if (yyssp >= yysslim && yygrowstack())
    {
        goto yyoverflow;
    }
    *++yyssp = yystate;
    *++yyvsp = yyval;
    goto yyloop;
yyoverflow:
    yyerror("yacc stack overflow");
yyabort:
    return (1);
yyaccept:
    return (0);
}
